@@ -28,12 +28,6 @@
 
 #ifdef HAVE_EXEMPI
 
-#define NS_XMP_REGIONS "http://www.metadataworkinggroup.com/schemas/regions/"
-#define NS_ST_DIM "http://ns.adobe.com/xap/1.0/sType/Dimensions#"
-#define NS_ST_AREA "http://ns.adobe.com/xmp/sType/Area#"
-
-#define REGION_LIST_REGEX "^mwg-rs:Regions/mwg-rs:RegionList\\[(\\d+)\\]"
-
 #include <exempi/xmp.h>
 #include <exempi/xmpconsts.h>
 
@@ -123,45 +117,6 @@ fix_white_balance (const gchar *wb)
 	}
 }
 
-static gchar *
-gps_coordinate_dup (const gchar *coordinates)
-{
-	static GRegex *reg = NULL;
-	GMatchInfo *info = NULL;
-
-	if (!reg) {
-		reg = g_regex_new ("([0-9]+),([0-9]+.[0-9]+)([A-Z])", 0, 0, NULL);
-	}
-
-	if (g_regex_match (reg, coordinates, 0, &info)) {
-		gchar *deg,*min,*ref;
-		gdouble r,d,m;
-
-		deg = g_match_info_fetch (info, 1);
-		min = g_match_info_fetch (info, 2);
-		ref = g_match_info_fetch (info, 3);
-
-		d = atof (deg);
-		m = atof (min);
-
-		r = d + m/60;
-
-		if ( (ref[0] == 'S') || (ref[0] == 'W')) {
-			r = r * -1;
-		}
-
-		g_free (deg);
-		g_free (min);
-		g_free (ref);
-                g_match_info_free (info);
-
-		return g_strdup_printf ("%f", r);
-	} else {
-                g_match_info_free (info);
-		return NULL;
-	}
-}
-
 /* We have an array, now recursively iterate over it's children.  Set
  * 'append' to true so that all values of the array are added under
  * one entry.
@@ -202,21 +157,16 @@ div_str_dup (const gchar *value)
 {
 	gchar *ret;
 	gchar *ptr = strchr (value, '/');
-
 	if (ptr) {
 		gchar *cpy = g_strdup (value);
 		gint a, b;
-
 		cpy [ptr - value] = '\0';
 		a = atoi (cpy);
 		b = atoi (cpy + (ptr - value) + 1);
-
-		if (b != 0) {
+		if (b != 0)
 			ret = g_strdup_printf ("%G", ((gdouble)((gdouble) a / (gdouble) b)));
-		} else {
+		else
 			ret = NULL;
-		}
-
 		g_free (cpy);
 	} else {
 		ret = g_strdup (value);
@@ -296,60 +246,27 @@ iterate_simple_qual (XmpPtr          xmp,
 static const gchar *
 fix_orientation (const gchar *orientation)
 {
-	if (orientation && g_ascii_strcasecmp (orientation, "1") == 0) {
+	if (orientation && g_ascii_strcasecmp (orientation, "top - left") == 0) {
 		return "nfo:orientation-top";
-	} else if (orientation && g_ascii_strcasecmp (orientation, "2") == 0) {
-		return  "nfo:orientation-top-mirror";
-	} else if (orientation && g_ascii_strcasecmp (orientation, "3") == 0) {
+	} else if (orientation && g_ascii_strcasecmp (orientation, "top - right") == 0) {
+			return  "nfo:orientation-top-mirror";
+	} else if (orientation && g_ascii_strcasecmp (orientation, "bottom - right") == 0) {
 		return "nfo:orientation-bottom-mirror";
-	} else if (orientation && g_ascii_strcasecmp (orientation, "4") == 0) {
+	} else if (orientation && g_ascii_strcasecmp (orientation, "bottom - left") == 0) {
 		return  "nfo:orientation-bottom";
-	} else if (orientation && g_ascii_strcasecmp (orientation, "5") == 0) {
+	} else if (orientation && g_ascii_strcasecmp (orientation, "left - top") == 0) {
 		return  "nfo:orientation-left-mirror";
-	} else if (orientation && g_ascii_strcasecmp (orientation, "6") == 0) {
+	} else if (orientation && g_ascii_strcasecmp (orientation, "right - top") == 0) {
 		return  "nfo:orientation-right";
-	} else if (orientation && g_ascii_strcasecmp (orientation, "7") == 0) {
+	} else if (orientation && g_ascii_strcasecmp (orientation, "right - bottom") == 0) {
 		return "nfo:orientation-right-mirror";
-	} else if (orientation && g_ascii_strcasecmp (orientation, "8") == 0) {
+	} else if (orientation && g_ascii_strcasecmp (orientation, "left - bottom") == 0) {
 		return  "nfo:orientation-left";
 	}
 
 	return  "nfo:orientation-top";
 }
 
-/*
- * In a path like: mwg-rs:Regions/mwg-rs:RegionList[2]/mwg-rs:Area/stArea:x
- * this function returns the "2" from RegionsList[2] 
- *  Note: The first element from a list is 1
- */
-static gint
-get_region_counter (const gchar *path) 
-{
-        static GRegex *regex = NULL;
-        GMatchInfo    *match_info = NULL;
-        gchar         *match;
-        gint           result;
-        
-        if (!regex) {
-                regex = g_regex_new (REGION_LIST_REGEX, 0, 0, NULL);
-        }
-
-        if (!g_regex_match (regex, path, 0, &match_info)) {
-                g_match_info_free (match_info);
-                return -1;
-        }
-
-        match = g_match_info_fetch (match_info, 1);
-        result =  g_strtod (match, NULL);
-
-        g_free (match);
-        g_match_info_free (match_info);
-
-        return result;
-}
-
-
-
 /* We have a simple element. Add any data we know about to the
  * hash table.
  */
@@ -362,22 +279,13 @@ iterate_simple (const gchar    *uri,
                 gboolean        append)
 {
 	gchar *name;
-	const gchar *p;
-	gchar *propname;
+	const gchar *index_;
 
-	p = strchr (path, ':');
-	if (!p) {
-		return;
-	}
+	name = g_strdup (strchr (path, ':') + 1);
+	index_ = strrchr (name, '[');
 
-	name = g_strdup (p + 1);
-
-	/* For 'dc:subject[1]' the name will be 'subject'.
-	 * This rule doesn't work for RegionLists
-	 */
-	p = strrchr (name, '[');
-	if (p) {
-		name[p - name] = '\0';
+	if (index_) {
+		name[index_ - name] = '\0';
 	}
 
 	/* Exif basic scheme */
@@ -395,6 +303,8 @@ iterate_simple (const gchar    *uri,
 			data->make = g_strdup (value);
 		} else if (!data->model && g_ascii_strcasecmp (name, "Model") == 0) {
 			data->model = g_strdup (value);
+		} else if (!data->orientation && g_ascii_strcasecmp (name, "Orientation") == 0) {
+			data->orientation = g_strdup (fix_orientation (value));
 		} else if (!data->flash && g_ascii_strcasecmp (name, "Flash") == 0) {
 			data->flash = g_strdup (fix_flash (value));
 		} else if (!data->metering_mode && g_ascii_strcasecmp (name, "MeteringMode") == 0) {
@@ -414,21 +324,6 @@ iterate_simple (const gchar    *uri,
 			data->white_balance = g_strdup (fix_white_balance (value));
 		} else if (!data->copyright && g_ascii_strcasecmp (name, "Copyright") == 0) {
 			data->copyright = g_strdup (value);
-		} else if (!data->gps_altitude && g_ascii_strcasecmp (name, "GPSAltitude") == 0) {
-			data->gps_altitude = div_str_dup (value);
-		} else if (!data->gps_altitude_ref && g_ascii_strcasecmp (name, "GPSAltitudeRef") == 0) {
-			data->gps_altitude_ref = g_strdup (value);
-		} else if (!data->gps_latitude && g_ascii_strcasecmp (name, "GPSLatitude") == 0) {
-			data->gps_latitude = gps_coordinate_dup (value);
-		} else if (!data->gps_longitude && g_ascii_strcasecmp (name, "GPSLongitude") == 0) {
-			data->gps_longitude = gps_coordinate_dup (value);
-		} else if (!data->gps_direction && g_ascii_strcasecmp (name, "GPSImgDirection") == 0) {
-			data->gps_direction = div_str_dup (value);
-		}
-		/* TIFF */
-	} else if (g_ascii_strcasecmp (schema, NS_TIFF) == 0) {
-		if (!data->orientation && g_ascii_strcasecmp (name, "Orientation") == 0) {
-			data->orientation = g_strdup (fix_orientation (value));
 		}
 		/* PDF*/
 	} else if (g_ascii_strcasecmp (schema, NS_PDF) == 0) {
@@ -532,60 +427,12 @@ iterate_simple (const gchar    *uri,
 		if (!data->rating && g_ascii_strcasecmp (name, "Rating") == 0) {
 			data->rating = g_strdup (value);
 		}
-	} else if (g_ascii_strcasecmp (schema, NS_XMP_REGIONS) == 0) {
-                if (g_str_has_prefix (path, "mwg-rs:Regions/mwg-rs:RegionList")) {
-	                TrackerXmpRegion *current_region;
-                        gint              position = get_region_counter (path);
+	}
 
-                        if (position == -1) {
-                                g_free (name);
-                                return;
-                        }
-
-                        /* First time a property appear for a region, we create the region */
-                        current_region = g_slist_nth_data (data->regions, position-1);
-                        if (current_region == NULL) {
-                                current_region = g_slice_new0 (TrackerXmpRegion);
-                                data->regions = g_slist_append (data->regions, current_region);
-                        }
-
-                        propname = g_strdup (strrchr (path, '/') + 1);
-
-                        if (!current_region->title && g_ascii_strcasecmp (propname, "mwg-rs:Name") == 0) {
-                                current_region->title = g_strdup (value);
-                        } else if (!current_region->description && g_ascii_strcasecmp (propname, "mwg-rs:Description") == 0) {
-                                current_region->description = g_strdup (value);
-                        } else if (!current_region->x && g_ascii_strcasecmp (propname, "stArea:x") == 0) {
-                                current_region->x = g_strdup (value);
-                        } else if (!current_region->y && g_ascii_strcasecmp (propname, "stArea:y") == 0) {
-                                current_region->y = g_strdup (value);
-                        } else if (!current_region->width && g_ascii_strcasecmp (propname, "stArea:w") == 0) {
-                                current_region->width = g_strdup (value);
-                        } else if (!current_region->height && g_ascii_strcasecmp (propname, "stArea:h") == 0) {
-                                current_region->height = g_strdup (value);
-
-                                /* Spec not clear about units
-                                 *  } else if (!current_region->unit
-                                 *             && g_ascii_strcasecmp (propname, "stArea:unit") == 0) {
-                                 *      current_region->unit = g_strdup (value);
-                                 *
-                                 *  we consider it always comes normalized
-                                */
-                        } else if (!current_region->type && g_ascii_strcasecmp (propname, "mwg-rs:Type") == 0) {
-                                current_region->type = g_strdup (value);
-                        } else if (g_str_has_prefix (strrchr (path, ']') + 2, "mwg-rs:Extensions")) {
-                                current_region->link_class = g_strdup (propname);
-                                current_region->link_uri = g_strdup (value);
-                        }
-
-                        g_free (propname);
-                }
-        }
 
 	g_free (name);
 }
 
-
 /* Iterate over the XMP, dispatching to the appropriate element type
  * (simple, simple w/qualifiers, or an array) handler.
  */
@@ -599,7 +446,6 @@ iterate (XmpPtr          xmp,
 	XmpStringPtr the_schema = xmp_string_new ();
 	XmpStringPtr the_path = xmp_string_new ();
 	XmpStringPtr the_prop = xmp_string_new ();
-
 	uint32_t opt;
 
 	while (xmp_iterator_next (iter, the_schema, the_path, the_prop, &opt)) {
@@ -615,20 +461,14 @@ iterate (XmpPtr          xmp,
 					iterate_simple (uri, data, schema, path, value, append);
 				}
 			}
-		} else if (XMP_IS_PROP_ARRAY (opt)) {
+		}
+		else if (XMP_IS_PROP_ARRAY (opt)) {
 			if (XMP_IS_ARRAY_ALTTEXT (opt)) {
 				iterate_alt_text (xmp, uri, data, schema, path);
 				xmp_iterator_skip (iter, XMP_ITER_SKIPSUBTREE);
 			} else {
 				iterate_array (xmp, uri, data, schema, path);
-
-                                /* Some dc: elements are handled as arrays by exempi.
-                                 * In those cases, to avoid duplicated values, is easier
-                                 * to skip the subtree.
-                                 */
-                                if (g_ascii_strcasecmp (schema, NS_DC) == 0) {
-                                        xmp_iterator_skip (iter, XMP_ITER_SKIPSUBTREE);
-                                }
+				xmp_iterator_skip (iter, XMP_ITER_SKIPSUBTREE);
 			}
 		}
 	}
@@ -638,15 +478,6 @@ iterate (XmpPtr          xmp,
 	xmp_string_free (the_schema);
 }
 
-static void
-register_namespace (const gchar *ns_uri,
-                    const gchar *suggested_prefix)
-{
-        if (!xmp_namespace_prefix (ns_uri, NULL)) {
-                xmp_register_namespace (ns_uri, suggested_prefix, NULL);
-        }
-}
-
 #endif /* HAVE_EXEMPI */
 
 static gboolean
@@ -665,10 +496,6 @@ parse_xmp (const gchar    *buffer,
 
 	xmp_init ();
 
-        register_namespace (NS_XMP_REGIONS, "mwg-rs");
-        register_namespace (NS_ST_DIM, "stDim");
-        register_namespace (NS_ST_AREA, "stArea");
-
 	xmp = xmp_new_empty ();
 	xmp_parse (xmp, buffer, len);
 
@@ -689,8 +516,6 @@ parse_xmp (const gchar    *buffer,
 
 #ifndef TRACKER_DISABLE_DEPRECATED
 
-// LCOV_EXCL_START
-
 /**
  * tracker_xmp_read:
  * @buffer: a chunk of data with xmp data in it.
@@ -723,29 +548,8 @@ tracker_xmp_read (const gchar    *buffer,
 	return parse_xmp (buffer, len, uri, data);
 }
 
-// LCOV_EXCL_STOP
-
 #endif /* TRACKER_DISABLE_DEPRECATED */
 
-static void
-xmp_region_free (gpointer data)
-{
-        TrackerXmpRegion *region = (TrackerXmpRegion *) data;
-
-        g_free (region->title);
-        g_free (region->description);
-        g_free (region->type);
-        g_free (region->x);
-        g_free (region->y);
-        g_free (region->width);
-        g_free (region->height);
-        g_free (region->link_class);
-        g_free (region->link_uri);
-
-        g_slice_free (TrackerXmpRegion, region);
-}
-
-
 /**
  * tracker_xmp_new:
  * @buffer: a chunk of data with xmp data in it.
@@ -833,38 +637,10 @@ tracker_xmp_free (TrackerXmpData *data)
 	g_free (data->country);
 	g_free (data->state);
 	g_free (data->city);
-	g_free (data->gps_altitude);
-	g_free (data->gps_altitude_ref);
-	g_free (data->gps_latitude);
-	g_free (data->gps_longitude);
-	g_free (data->gps_direction);
 
-        g_slist_free_full (data->regions, xmp_region_free);
 	g_free (data);
 }
 
-
-static const gchar *
-fix_region_type (const gchar *region_type)
-{
-        if (region_type == NULL) {
-                return "nfo:region-content-undefined";
-        }
-
-        if (g_ascii_strcasecmp (region_type, "Face")) {
-                return "nfo:roi-content-face";
-        } else if (g_ascii_strcasecmp (region_type, "Pet")) {
-                return "nfo:roi-content-pet";
-        } else if (g_ascii_strcasecmp (region_type, "Focus")) {
-                return "nfo:roi-content-focus";
-        } else if (g_ascii_strcasecmp (region_type, "BarCode")) {
-                return "nfo:roi-content-barcode";
-        }
-
-        return "nfo:roi-content-undefined";
-}
-
-
 /**
  * tracker_xmp_apply:
  * @metadata: the metadata object to apply XMP data to.
@@ -873,9 +649,6 @@ fix_region_type (const gchar *region_type)
  *
  * This function applies all data in @data to @metadata.
  *
- * This function also calls tracker_xmp_apply_regions(), so there is
- * no need to call both functions.
- *
  * Returns: %TRUE if the @data was applied to @metadata successfully,
  * otherwise %FALSE is returned.
  *
@@ -884,14 +657,13 @@ fix_region_type (const gchar *region_type)
 gboolean
 tracker_xmp_apply (TrackerSparqlBuilder *preupdate,
                    TrackerSparqlBuilder *metadata,
+                   GString              *where,
                    const gchar          *uri,
                    TrackerXmpData       *data)
 {
 	GPtrArray *keywords;
 	guint i;
-	GString *where = NULL;
 
-	g_return_val_if_fail (TRACKER_SPARQL_IS_BUILDER (preupdate), FALSE);
 	g_return_val_if_fail (TRACKER_SPARQL_IS_BUILDER (metadata), FALSE);
 	g_return_val_if_fail (uri != NULL, FALSE);
 	g_return_val_if_fail (data != NULL, FALSE);
@@ -932,10 +704,6 @@ tracker_xmp_apply (TrackerSparqlBuilder *preupdate,
 		tracker_sparql_builder_predicate (metadata, "nao:hasTag");
 		tracker_sparql_builder_object_variable (metadata, var);
 
-		if (where == NULL) {
-			where = g_string_new ("} } WHERE { {\n");
-		}
-
 		g_string_append_printf (where, "?%s a nao:Tag ; nao:prefLabel \"%s\" .\n", var, escaped);
 
 		g_free (var);
@@ -1117,8 +885,8 @@ tracker_xmp_apply (TrackerSparqlBuilder *preupdate,
 		tracker_sparql_builder_object_blank_close (metadata);
 	}
 
-	if (data->address || data->state || data->country || data->city ||
-	    data->gps_altitude || data->gps_latitude || data->gps_longitude) {
+	if (data->address || data->country || data->city) {
+		gchar *addruri;
 
 		tracker_sparql_builder_predicate (metadata, "slo:location");
 
@@ -1126,188 +894,44 @@ tracker_xmp_apply (TrackerSparqlBuilder *preupdate,
 		tracker_sparql_builder_predicate (metadata, "a");
 		tracker_sparql_builder_object (metadata, "slo:GeoLocation");
 
-		if (data->address || data->state || data->country || data->city) {
-			gchar *addruri;
+		addruri = tracker_sparql_get_uuid_urn ();
 
-			addruri = tracker_sparql_get_uuid_urn ();
-
-			tracker_sparql_builder_predicate (metadata, "slo:postalAddress");
-			tracker_sparql_builder_object_iri (metadata, addruri);
-
-			tracker_sparql_builder_insert_open (preupdate, NULL);
-			tracker_sparql_builder_subject_iri (preupdate, addruri);
-
-			g_free (addruri);
-
-			tracker_sparql_builder_predicate (preupdate, "a");
-			tracker_sparql_builder_object (preupdate, "nco:PostalAddress");
-
-			if (data->address) {
-				tracker_sparql_builder_predicate (preupdate, "nco:streetAddress");
-				tracker_sparql_builder_object_unvalidated (preupdate, data->address);
-			}
-
-			if (data->state) {
-				tracker_sparql_builder_predicate (preupdate, "nco:region");
-				tracker_sparql_builder_object_unvalidated (preupdate, data->state);
-			}
-
-			if (data->city) {
-				tracker_sparql_builder_predicate (preupdate, "nco:locality");
-				tracker_sparql_builder_object_unvalidated (preupdate, data->city);
-			}
-
-			if (data->country) {
-				tracker_sparql_builder_predicate (preupdate, "nco:country");
-				tracker_sparql_builder_object_unvalidated (preupdate, data->country);
-			}
-
-			tracker_sparql_builder_insert_close (preupdate);
-		}
-
-		/* FIXME We are not handling the altitude ref here */
-
-		if (data->gps_altitude) {
-			tracker_sparql_builder_predicate (metadata, "slo:altitude");
-			tracker_sparql_builder_object_unvalidated (metadata, data->gps_altitude);
-		}
-
-		if (data->gps_latitude) {
-			tracker_sparql_builder_predicate (metadata, "slo:latitude");
-			tracker_sparql_builder_object_unvalidated (metadata, data->gps_latitude);
-		}
-
-		if (data->gps_longitude) {
-			tracker_sparql_builder_predicate (metadata, "slo:longitude");
-			tracker_sparql_builder_object_unvalidated (metadata, data->gps_longitude);
-		}
+		tracker_sparql_builder_predicate (metadata, "slo:postalAddress");
+		tracker_sparql_builder_object_iri (metadata, addruri);
 
 		tracker_sparql_builder_object_blank_close (metadata); /* GeoLocation */
-	}
 
-	if (data->gps_direction) {
-		tracker_sparql_builder_predicate (metadata, "nfo:heading");
-		tracker_sparql_builder_object_unvalidated (metadata, data->gps_direction);
-	}
+		tracker_sparql_builder_insert_open (preupdate, NULL);
+		tracker_sparql_builder_subject_iri (preupdate, addruri);
 
-	if (where != NULL) {
-		tracker_sparql_builder_append (metadata, where->str);
-		g_string_free (where, TRUE);
-	}
+		g_free (addruri);
 
-        if (data->regions) {
-	        tracker_xmp_apply_regions (preupdate, metadata, NULL, data);
-        }
+		tracker_sparql_builder_predicate (preupdate, "a");
+		tracker_sparql_builder_object (preupdate, "nco:PostalAddress");
+
+		if (data->address) {
+			tracker_sparql_builder_predicate (preupdate, "nco:streetAddress");
+			tracker_sparql_builder_object_unvalidated (preupdate, data->address);
+		}
+
+		if (data->state) {
+			tracker_sparql_builder_predicate (preupdate, "nco:region");
+			tracker_sparql_builder_object_unvalidated (preupdate, data->state);
+		}
+
+		if (data->city) {
+			tracker_sparql_builder_predicate (preupdate, "nco:locality");
+			tracker_sparql_builder_object_unvalidated (preupdate, data->city);
+		}
+
+		if (data->country) {
+			tracker_sparql_builder_predicate (preupdate, "nco:country");
+			tracker_sparql_builder_object_unvalidated (preupdate, data->country);
+		}
+
+		tracker_sparql_builder_insert_close (preupdate);
+
+	}
 
 	return TRUE;
 }
-
-/**
- * tracker_xmp_apply_regions:
- * @preupdate: the preupdate object to apply XMP data to.
- * @metadata: the metadata object to apply XMP data to.
- * @graph: the graph to apply XMP data to.
- * @data: the data to push into @preupdate and @metadata.
- *
- * This function applies all regional @data to @preupdate and
- * @metadata. Regional data exists for image formats like JPEG, PNG,
- * etc. where parts of the image refer to areas of interest. This can
- * be people's faces, places to focus, barcodes, etc. The regional
- * data describes the title, height, width, X, Y and can occur
- * multiple times in a given file.
- *
- * This data usually is standardized between image formats and that's
- * what makes this function different to tracker_xmp_apply() which is
- * useful for XMP files only.
- *
- * Returns: %TRUE if the @data was applied to @preupdate and @metadata
- * successfully, otherwise %FALSE is returned.
- *
- * Since: 0.10.26
- **/
-gboolean
-tracker_xmp_apply_regions (TrackerSparqlBuilder *preupdate,
-                           TrackerSparqlBuilder *metadata,
-                           const gchar          *graph,
-                           TrackerXmpData       *data)
-{
-        GSList *iter;
-
-        g_return_val_if_fail (TRACKER_SPARQL_IS_BUILDER (preupdate), FALSE);
-        g_return_val_if_fail (TRACKER_SPARQL_IS_BUILDER (metadata), FALSE);
-        g_return_val_if_fail (data != NULL, FALSE);
-
-        if (!data->regions) {
-                return TRUE;
-        }
-
-        for (iter = data->regions; iter != NULL; iter = iter->next) {
-	        TrackerXmpRegion *region;
-	        gchar *uuid;
-
-                region = (TrackerXmpRegion *) iter->data;
-                uuid = tracker_sparql_get_uuid_urn ();
-
-		tracker_sparql_builder_insert_open (preupdate, NULL);
-		if (graph) {
-			tracker_sparql_builder_graph_open (preupdate, graph);
-		}
-
-		tracker_sparql_builder_subject_iri (preupdate, uuid);
-		tracker_sparql_builder_predicate (preupdate, "a");
-		tracker_sparql_builder_object (preupdate, "nfo:RegionOfInterest");
-
-                if (region->title) {
-                        tracker_sparql_builder_predicate (preupdate, "nie:title");
-                        tracker_sparql_builder_object_string (preupdate, region->title);
-                }
-
-                if (region->description) {
-                        tracker_sparql_builder_predicate (preupdate, "nie:description");
-                        tracker_sparql_builder_object_string (preupdate, region->description);
-                }
-
-                if (region->type) {
-                        tracker_sparql_builder_predicate (preupdate, "nfo:regionOfInterestType");
-                        tracker_sparql_builder_object (preupdate, fix_region_type (region->type));
-                }
-
-                if (region->x) {
-                        tracker_sparql_builder_predicate (preupdate, "nfo:regionOfInterestX");
-                        tracker_sparql_builder_object_unvalidated (preupdate, region->x);
-                }
-
-                if (region->y) {
-                        tracker_sparql_builder_predicate (preupdate, "nfo:regionOfInterestY");
-                        tracker_sparql_builder_object_unvalidated (preupdate, region->y);
-                }
-
-                if (region->width) {
-                        tracker_sparql_builder_predicate (preupdate, "nfo:regionOfInterestWidth");
-                        tracker_sparql_builder_object_unvalidated (preupdate, region->width);
-                }
-
-                if (region->height) {
-                        tracker_sparql_builder_predicate (preupdate, "nfo:regionOfInterestHeight");
-                        tracker_sparql_builder_object_unvalidated (preupdate, region->height);
-                }
-
-                if (region->link_uri && region->link_class) {
-                        tracker_sparql_builder_predicate (preupdate, "nfo:roiRefersTo");
-                        tracker_sparql_builder_object_iri (preupdate, region->link_uri);
-                }
-
-		if (graph) {
-			tracker_sparql_builder_graph_close (preupdate);
-		}
-		tracker_sparql_builder_insert_close (preupdate);
-
-                /* Handle non-preupdate metadata */
-                tracker_sparql_builder_predicate (metadata, "nfo:hasRegionOfInterest");
-                tracker_sparql_builder_object_iri (metadata, uuid);
-
-                g_free (uuid);
-        }
-
-        return TRUE;
-}
