@@ -216,24 +216,25 @@ tracker_marshal_VOID__DOUBLE_UINT_UINT_UINT_UINT (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING,DOUBLE (tracker-marshal.list:5) */
+/* VOID:STRING,DOUBLE,INT (tracker-marshal.list:5) */
 void
-tracker_marshal_VOID__STRING_DOUBLE (GClosure     *closure,
-                                     GValue       *return_value G_GNUC_UNUSED,
-                                     guint         n_param_values,
-                                     const GValue *param_values,
-                                     gpointer      invocation_hint G_GNUC_UNUSED,
-                                     gpointer      marshal_data)
+tracker_marshal_VOID__STRING_DOUBLE_INT (GClosure     *closure,
+                                         GValue       *return_value G_GNUC_UNUSED,
+                                         guint         n_param_values,
+                                         const GValue *param_values,
+                                         gpointer      invocation_hint G_GNUC_UNUSED,
+                                         gpointer      marshal_data)
 {
-  typedef void (*GMarshalFunc_VOID__STRING_DOUBLE) (gpointer     data1,
-                                                    gpointer     arg_1,
-                                                    gdouble      arg_2,
-                                                    gpointer     data2);
-  register GMarshalFunc_VOID__STRING_DOUBLE callback;
+  typedef void (*GMarshalFunc_VOID__STRING_DOUBLE_INT) (gpointer     data1,
+                                                        gpointer     arg_1,
+                                                        gdouble      arg_2,
+                                                        gint         arg_3,
+                                                        gpointer     data2);
+  register GMarshalFunc_VOID__STRING_DOUBLE_INT callback;
   register GCClosure *cc = (GCClosure*) closure;
   register gpointer data1, data2;
 
-  g_return_if_fail (n_param_values == 3);
+  g_return_if_fail (n_param_values == 4);
 
   if (G_CCLOSURE_SWAP_DATA (closure))
     {
@@ -245,11 +246,12 @@ tracker_marshal_VOID__STRING_DOUBLE (GClosure     *closure,
       data1 = g_value_peek_pointer (param_values + 0);
       data2 = closure->data;
     }
-  callback = (GMarshalFunc_VOID__STRING_DOUBLE) (marshal_data ? marshal_data : cc->callback);
+  callback = (GMarshalFunc_VOID__STRING_DOUBLE_INT) (marshal_data ? marshal_data : cc->callback);
 
   callback (data1,
             g_marshal_value_peek_string (param_values + 1),
             g_marshal_value_peek_double (param_values + 2),
+            g_marshal_value_peek_int (param_values + 3),
             data2);
 }
 
@@ -290,25 +292,26 @@ tracker_marshal_VOID__STRING_STRING (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING,STRING,DOUBLE (tracker-marshal.list:7) */
+/* VOID:STRING,STRING,DOUBLE,INT (tracker-marshal.list:7) */
 void
-tracker_marshal_VOID__STRING_STRING_DOUBLE (GClosure     *closure,
-                                            GValue       *return_value G_GNUC_UNUSED,
-                                            guint         n_param_values,
-                                            const GValue *param_values,
-                                            gpointer      invocation_hint G_GNUC_UNUSED,
-                                            gpointer      marshal_data)
+tracker_marshal_VOID__STRING_STRING_DOUBLE_INT (GClosure     *closure,
+                                                GValue       *return_value G_GNUC_UNUSED,
+                                                guint         n_param_values,
+                                                const GValue *param_values,
+                                                gpointer      invocation_hint G_GNUC_UNUSED,
+                                                gpointer      marshal_data)
 {
-  typedef void (*GMarshalFunc_VOID__STRING_STRING_DOUBLE) (gpointer     data1,
-                                                           gpointer     arg_1,
-                                                           gpointer     arg_2,
-                                                           gdouble      arg_3,
-                                                           gpointer     data2);
-  register GMarshalFunc_VOID__STRING_STRING_DOUBLE callback;
+  typedef void (*GMarshalFunc_VOID__STRING_STRING_DOUBLE_INT) (gpointer     data1,
+                                                               gpointer     arg_1,
+                                                               gpointer     arg_2,
+                                                               gdouble      arg_3,
+                                                               gint         arg_4,
+                                                               gpointer     data2);
+  register GMarshalFunc_VOID__STRING_STRING_DOUBLE_INT callback;
   register GCClosure *cc = (GCClosure*) closure;
   register gpointer data1, data2;
 
-  g_return_if_fail (n_param_values == 4);
+  g_return_if_fail (n_param_values == 5);
 
   if (G_CCLOSURE_SWAP_DATA (closure))
     {
@@ -320,12 +323,13 @@ tracker_marshal_VOID__STRING_STRING_DOUBLE (GClosure     *closure,
       data1 = g_value_peek_pointer (param_values + 0);
       data2 = closure->data;
     }
-  callback = (GMarshalFunc_VOID__STRING_STRING_DOUBLE) (marshal_data ? marshal_data : cc->callback);
+  callback = (GMarshalFunc_VOID__STRING_STRING_DOUBLE_INT) (marshal_data ? marshal_data : cc->callback);
 
   callback (data1,
             g_marshal_value_peek_string (param_values + 1),
             g_marshal_value_peek_string (param_values + 2),
             g_marshal_value_peek_double (param_values + 3),
+            g_marshal_value_peek_int (param_values + 4),
             data2);
 }
 
@@ -370,7 +374,50 @@ tracker_marshal_VOID__STRING_STRING_BOOLEAN_BOOLEAN (GClosure     *closure,
             data2);
 }
 
-/* BOOL:OBJECT,OBJECT,OBJECT (tracker-marshal.list:9) */
+/* VOID:STRING,STRING,STRING,BOOLEAN,BOOLEAN (tracker-marshal.list:9) */
+void
+tracker_marshal_VOID__STRING_STRING_STRING_BOOLEAN_BOOLEAN (GClosure     *closure,
+                                                            GValue       *return_value G_GNUC_UNUSED,
+                                                            guint         n_param_values,
+                                                            const GValue *param_values,
+                                                            gpointer      invocation_hint G_GNUC_UNUSED,
+                                                            gpointer      marshal_data)
+{
+  typedef void (*GMarshalFunc_VOID__STRING_STRING_STRING_BOOLEAN_BOOLEAN) (gpointer     data1,
+                                                                           gpointer     arg_1,
+                                                                           gpointer     arg_2,
+                                                                           gpointer     arg_3,
+                                                                           gboolean     arg_4,
+                                                                           gboolean     arg_5,
+                                                                           gpointer     data2);
+  register GMarshalFunc_VOID__STRING_STRING_STRING_BOOLEAN_BOOLEAN callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+
+  g_return_if_fail (n_param_values == 6);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_VOID__STRING_STRING_STRING_BOOLEAN_BOOLEAN) (marshal_data ? marshal_data : cc->callback);
+
+  callback (data1,
+            g_marshal_value_peek_string (param_values + 1),
+            g_marshal_value_peek_string (param_values + 2),
+            g_marshal_value_peek_string (param_values + 3),
+            g_marshal_value_peek_boolean (param_values + 4),
+            g_marshal_value_peek_boolean (param_values + 5),
+            data2);
+}
+
+/* BOOL:OBJECT,OBJECT,OBJECT (tracker-marshal.list:10) */
 void
 tracker_marshal_BOOLEAN__OBJECT_OBJECT_OBJECT (GClosure     *closure,
                                                GValue       *return_value G_GNUC_UNUSED,
@@ -413,7 +460,7 @@ tracker_marshal_BOOLEAN__OBJECT_OBJECT_OBJECT (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOL:OBJECT,OBJECT (tracker-marshal.list:10) */
+/* BOOL:OBJECT,OBJECT (tracker-marshal.list:11) */
 void
 tracker_marshal_BOOLEAN__OBJECT_OBJECT (GClosure     *closure,
                                         GValue       *return_value G_GNUC_UNUSED,
@@ -454,7 +501,7 @@ tracker_marshal_BOOLEAN__OBJECT_OBJECT (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOL:OBJECT,POINTER (tracker-marshal.list:11) */
+/* BOOL:OBJECT,POINTER (tracker-marshal.list:12) */
 void
 tracker_marshal_BOOLEAN__OBJECT_POINTER (GClosure     *closure,
                                          GValue       *return_value G_GNUC_UNUSED,
@@ -495,7 +542,7 @@ tracker_marshal_BOOLEAN__OBJECT_POINTER (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOL:OBJECT (tracker-marshal.list:12) */
+/* BOOL:OBJECT (tracker-marshal.list:13) */
 void
 tracker_marshal_BOOLEAN__OBJECT (GClosure     *closure,
                                  GValue       *return_value G_GNUC_UNUSED,
