@@ -129,11 +129,12 @@ tracker_miner_manager_class_init (TrackerMinerManagerClass *klass)
 	 * @miner: miner reference
 	 * @status: miner status
 	 * @progress: miner progress, from 0 to 1
+	 * @remaining_time: remaining processing time
 	 *
 	 * The ::miner-progress signal is meant to report status/progress changes
 	 * in any tracked miner.
 	 *
-	 * Since: 0.8
+	 * Since: 0.12
 	 **/
 	signals [MINER_PROGRESS] =
 		g_signal_new ("miner-progress",
@@ -141,11 +142,12 @@ tracker_miner_manager_class_init (TrackerMinerManagerClass *klass)
 		              G_SIGNAL_RUN_LAST,
 		              G_STRUCT_OFFSET (TrackerMinerManagerClass, miner_progress),
 		              NULL, NULL,
-		              tracker_marshal_VOID__STRING_STRING_DOUBLE,
-		              G_TYPE_NONE, 3,
+		              tracker_marshal_VOID__STRING_STRING_DOUBLE_INT,
+		              G_TYPE_NONE, 4,
 		              G_TYPE_STRING,
 		              G_TYPE_STRING,
-		              G_TYPE_DOUBLE);
+		              G_TYPE_DOUBLE,
+		              G_TYPE_INT);
 	/**
 	 * TrackerMinerManager::miner-paused
 	 * @manager: the #TrackerMinerManager
@@ -334,10 +336,11 @@ miner_progress_changed (GDBusConnection *connection,
 	MinerData *data = user_data;
 	const gchar *status = NULL;
 	gdouble progress = 0;
+	gint remaining_time = -1;
 
-	g_variant_get (parameters, "(&sd)", &status, &progress);
+	g_variant_get (parameters, "(&sdi)", &status, &progress, &remaining_time);
 	if (data->manager) {
-		g_signal_emit (data->manager, signals[MINER_PROGRESS], 0, data->dbus_name, status, progress);
+		g_signal_emit (data->manager, signals[MINER_PROGRESS], 0, data->dbus_name, status, progress, remaining_time);
 	}
 }
 
@@ -601,8 +604,11 @@ tracker_miner_manager_new_full (gboolean   auto_start,
 	                          &inner_error,
 	                          "auto-start", auto_start,
 	                          NULL);
-	if (inner_error)
-		g_propagate_error (error, inner_error);
+	if (!manager) {
+		g_critical ("Couldn't create new TrackerMinerManager: '%s'",
+		            inner_error ? inner_error->message : "unknown error");
+		g_clear_error (&inner_error);
+	}
 
 	return manager;
 }
@@ -614,9 +620,9 @@ tracker_miner_manager_new_full (gboolean   auto_start,
  * Returns a list of references for all active miners. Active miners
  * are miners which are running within a process.
  *
- * Returns: (transfer full) (element-type utf8): a #GSList which must
- * be freed with g_slist_free() and all contained data with g_free().
- * Otherwise %NULL is returned if there are no miners.
+ * Returns: (transfer full): a #GSList which must be freed with g_slist_free() and all
+ * contained data with g_free(). Otherwise %NULL is returned if there
+ * are no miners.
  *
  * Since: 0.8
  **/
@@ -792,9 +798,9 @@ initialize_miners_data (TrackerMinerManager *manager)
  * miners are miners which may or may not be running in a process at
  * the current time.
  *
- * Returns: (transfer full) (element-type utf8): a #GSList which must
- * be freed with g_slist_free() and all contained data with g_free().
- * Otherwise %NULL is returned if there are no miners.
+ * Returns: (transfer full): a #GSList which must be freed with g_slist_free() and all
+ * contained data with g_free(). Otherwise %NULL is returned if there
+ * are no miners.
  *
  * Since: 0.8
  **/
@@ -821,7 +827,7 @@ tracker_miner_manager_get_available (TrackerMinerManager *manager)
  * @manager: a #TrackerMinerManager.
  * @miner: miner reference
  * @reason: reason to pause
- * @cookie: (out) (allow-none): return location for the pause cookie ID
+ * @cookie: return location for the pause cookie ID
  *
  * Asks @miner to pause. a miner could be paused by
  * several reasons, and its activity won't be resumed
@@ -888,80 +894,6 @@ tracker_miner_manager_pause (TrackerMinerManager *manager,
 	return TRUE;
 }
 
-/**
- * tracker_miner_manager_pause_for_process:
- * @manager: a #TrackerMinerManager.
- * @miner: miner reference
- * @reason: reason to pause
- * @cookie: (out) (allow-none): return location for the pause cookie ID
- *
- * This function operates exactly the same way as
- * tracker_miner_manager_pause() with the exception that if the calling
- * process dies, the pause is resumed. This API is useful for cases
- * where the calling process has a risk of crashing without resuming
- * the pause.
- *
- * Returns: %TRUE if the miner was paused successfully, otherwise
- * %FALSE.
- *
- * Since: 0.10.15
- **/
-gboolean
-tracker_miner_manager_pause_for_process (TrackerMinerManager *manager,
-                                         const gchar         *miner,
-                                         const gchar         *reason,
-                                         guint32             *cookie)
-{
-	GDBusProxy *proxy;
-	const gchar *app_name;
-	GError *error = NULL;
-	GVariant *v;
-
-	g_return_val_if_fail (TRACKER_IS_MINER_MANAGER (manager), FALSE);
-	g_return_val_if_fail (miner != NULL, FALSE);
-	g_return_val_if_fail (reason != NULL, FALSE);
-
-	proxy = find_miner_proxy (manager, miner, TRUE);
-
-	if (!proxy) {
-		g_critical ("No D-Bus proxy found for miner '%s'", miner);
-		return FALSE;
-	}
-
-	/* Find a reasonable app name */
-	app_name = g_get_application_name ();
-
-	if (!app_name) {
-		app_name = g_get_prgname ();
-	}
-
-	if (!app_name) {
-		app_name = "TrackerMinerManager client";
-	}
-
-	v = g_dbus_proxy_call_sync (proxy,
-	                            "PauseForProcess",
-	                            g_variant_new ("(ss)", app_name, reason),
-	                            G_DBUS_CALL_FLAGS_NONE,
-	                            -1,
-	                            NULL,
-	                            &error);
-
-	if (error) {
-		g_critical ("Could not pause miner '%s': %s", miner, error->message);
-		g_error_free (error);
-		return FALSE;
-	}
-
-	if (cookie) {
-		g_variant_get (v, "(i)", cookie);
-	}
-
-	g_variant_unref (v);
-
-	return TRUE;
-}
-
 /**
  * tracker_miner_manager_resume:
  * @manager: a #TrackerMinerManager
@@ -1069,27 +1001,32 @@ tracker_miner_manager_is_active (TrackerMinerManager *manager,
  * @miner: miner reference
  * @status: (out) (allow-none): return location for status
  * @progress: (out) (allow-none): return location for progress
+ * @remaining_time: (out) (allow-none): return location for remaining time
  *
- * Returns the current status and progress for @miner.
+ * Returns the current status, progress and remaining time for @miner.
+ * @remaining_time will be 0 if not possible to compute it yet,
+ * and less than zero if it is not applicable.
  *
  * Returns: %TRUE if the status could be retrieved successfully,
  * otherwise %FALSE
  *
- * Since: 0.8
+ * Since: 0.12
  **/
 gboolean
 tracker_miner_manager_get_status (TrackerMinerManager  *manager,
                                   const gchar          *miner,
                                   gchar               **status,
-                                  gdouble              *progress)
+                                  gdouble              *progress,
+                                  gint                 *remaining_time)
 {
 	GDBusProxy *proxy;
-	GError *error = NULL;
-	gdouble p;
-	GVariant *v;
 
 	g_return_val_if_fail (TRACKER_IS_MINER_MANAGER (manager), FALSE);
 	g_return_val_if_fail (miner != NULL, FALSE);
+	/* At least one of them should be asked */
+	g_return_val_if_fail (status != NULL ||
+	                      progress != NULL ||
+	                      remaining_time != NULL, FALSE);
 
 	proxy = find_miner_proxy (manager, miner, TRUE);
 
@@ -1098,54 +1035,78 @@ tracker_miner_manager_get_status (TrackerMinerManager  *manager,
 		return FALSE;
 	}
 
-	v = g_dbus_proxy_call_sync (proxy,
-	                            "GetProgress",
-	                            NULL,
-	                            G_DBUS_CALL_FLAGS_NONE,
-	                            -1,
-	                            NULL,
-	                            &error);
+	if (progress) {
+		GError *error = NULL;
+		GVariant *v;
 
-	if (error) {
-		/* We handle this error as a special case, some
-		 * plugins don't have .service files.
-		 */
-		if (error->code != G_DBUS_ERROR_SERVICE_UNKNOWN) {
-			g_critical ("Could not get miner progress for '%s': %s", miner,
-			            error->message);
+		v = g_dbus_proxy_call_sync (proxy,
+		                            "GetProgress",
+		                            NULL,
+		                            G_DBUS_CALL_FLAGS_NONE,
+		                            -1,
+		                            NULL,
+		                            &error);
+		if (error) {
+			/* We handle this error as a special case, some
+			 * plugins don't have .service files.
+			 */
+			if (error->code != G_DBUS_ERROR_SERVICE_UNKNOWN) {
+				g_critical ("Could not get miner progress for '%s': %s", miner,
+				            error->message);
+			}
+
+			g_error_free (error);
+
+			return FALSE;
 		}
 
-		g_error_free (error);
-
-		return FALSE;
-	}
-
-	g_variant_get (v, "(d)", &p);
-	g_variant_unref (v);
-
-	v = g_dbus_proxy_call_sync (proxy,
-	                            "GetStatus",
-	                            NULL,
-	                            G_DBUS_CALL_FLAGS_NONE,
-	                            -1,
-	                            NULL,
-	                            &error);
-
-	if (error) {
-		g_critical ("Could not get miner status for '%s': %s", miner,
-		            error->message);
-		g_error_free (error);
-		return FALSE;
+		g_variant_get (v, "(d)", progress);
+		g_variant_unref (v);
 	}
 
 	if (status) {
+		GError *error = NULL;
+		GVariant *v;
+
+		v = g_dbus_proxy_call_sync (proxy,
+		                            "GetStatus",
+		                            NULL,
+		                            G_DBUS_CALL_FLAGS_NONE,
+		                            -1,
+		                            NULL,
+		                            &error);
+		if (error) {
+			g_critical ("Could not get miner status for '%s': %s", miner,
+			            error->message);
+			g_error_free (error);
+			return FALSE;
+		}
+
 		g_variant_get (v, "(s)", status);
+		g_variant_unref (v);
 	}
 
-	g_variant_unref (v);
+	if (remaining_time) {
+		GError *error = NULL;
+		GVariant *v;
 
-	if (progress) {
-		*progress = p;
+		v = g_dbus_proxy_call_sync (proxy,
+		                            "GetRemainingTime",
+		                            NULL,
+		                            G_DBUS_CALL_FLAGS_NONE,
+		                            -1,
+		                            NULL,
+		                            &error);
+		if (error) {
+			g_critical ("Could not get miner remaining processing "
+			            "time for '%s': %s", miner,
+			            error->message);
+			g_error_free (error);
+			return FALSE;
+		}
+
+		g_variant_get (v, "(i)", remaining_time);
+		g_variant_unref (v);
 	}
 
 	return TRUE;
@@ -1155,10 +1116,8 @@ tracker_miner_manager_get_status (TrackerMinerManager  *manager,
  * tracker_miner_manager_is_paused:
  * @manager: a #TrackerMinerManager
  * @miner: miner reference
- * @applications: (out callee-allocates) (allow-none) (transfer full):
- * return location for application names.
- * @reasons: (out callee-allocates) (allow-none) (transfer full):
- * return location for pause reasons.
+ * @applications: (out callee-allocates) (allow-none) (transfer full): return location for application names.
+ * @reasons: (out callee-allocates) (allow-none) (transfer full): return location for pause reasons.
  *
  * This function either returns %FALSE if the miner is not paused,
  * or returns %TRUE and fills in @applications and @reasons with
@@ -1318,7 +1277,6 @@ tracker_miner_manager_get_description (TrackerMinerManager *manager,
  * Returns: %TRUE on success, otherwise %FALSE.
  *
  * Since: 0.8
- * Deprecated since 0.12
  **/
 gboolean
 tracker_miner_manager_ignore_next_update (TrackerMinerManager *manager,
