@@ -106,10 +106,6 @@ gboolean             tracker_miner_manager_pause              (TrackerMinerManag
                                                                const gchar          *miner,
                                                                const gchar          *reason,
                                                                guint32              *cookie);
-gboolean             tracker_miner_manager_pause_for_process  (TrackerMinerManager  *manager,
-                                                               const gchar          *miner,
-                                                               const gchar          *reason,
-                                                               guint32              *cookie);
 gboolean             tracker_miner_manager_resume             (TrackerMinerManager  *manager,
                                                                const gchar          *miner,
                                                                guint32               cookie);
@@ -122,7 +118,8 @@ gboolean             tracker_miner_manager_is_paused          (TrackerMinerManag
 gboolean             tracker_miner_manager_get_status         (TrackerMinerManager  *manager,
                                                                const gchar          *miner,
                                                                gchar               **status,
-                                                               gdouble              *progress);
+                                                               gdouble              *progress,
+                                                               gint                 *remaining_time);
 gboolean             tracker_miner_manager_ignore_next_update (TrackerMinerManager  *manager,
                                                                const gchar          *miner,
                                                                const gchar         **urls);
