@@ -37,18 +37,17 @@ typedef struct TrackerConfig      TrackerConfig;
 typedef struct TrackerConfigClass TrackerConfigClass;
 
 struct TrackerConfig {
-	TrackerConfigFile parent;
+	GSettings parent;
+	gpointer priv;
 };
 
 struct TrackerConfigClass {
-	TrackerConfigFileClass parent_class;
+	GSettingsClass parent_class;
 };
 
 GType          tracker_config_get_type                             (void) G_GNUC_CONST;
 
 TrackerConfig *tracker_config_new                                  (void);
-TrackerConfig *tracker_config_new_with_domain                      (const gchar *domain);
-
 gboolean       tracker_config_save                                 (TrackerConfig *config);
 
 gint           tracker_config_get_verbosity                        (TrackerConfig *config);
@@ -70,7 +69,6 @@ GSList *       tracker_config_get_ignored_directories_with_content (TrackerConfi
 GSList *       tracker_config_get_ignored_files                    (TrackerConfig *config);
 gint           tracker_config_get_crawling_interval                (TrackerConfig *config);
 gint           tracker_config_get_removable_days_threshold         (TrackerConfig *config);
-gboolean       tracker_config_get_enable_writeback                 (TrackerConfig *config);
 
 void           tracker_config_set_verbosity                        (TrackerConfig *config,
                                                                     gint           value);
@@ -106,8 +104,6 @@ void           tracker_config_set_crawling_interval                (TrackerConfi
                                                                     gint           interval);
 void           tracker_config_set_removable_days_threshold         (TrackerConfig *config,
                                                                     gint           value);
-void           tracker_config_set_enable_writeback                 (TrackerConfig *config,
-                                                                    gboolean       value);
 
 /*
  * Convenience functions:
