@@ -106,111 +106,16 @@ miner_applications_initable_iface_init (GInitableIface *iface)
 	iface->init = miner_applications_initable_init;
 }
 
-static void
-miner_applications_basedir_add (TrackerMinerFS *fs,
-                                const gchar    *basedir)
-{
-	GFile *file;
-	gchar *path;
-
-	/* Add $dir/applications */
-	path = g_build_filename (basedir, "applications", NULL);
-	file = g_file_new_for_path (path);
-	g_message ("  Adding:'%s'", path);
-	tracker_miner_fs_directory_add (fs, file, TRUE);
-	g_object_unref (file);
-	g_free (path);
-
-	/* Add $dir/desktop-directories */
-	path = g_build_filename (basedir, "desktop-directories", NULL);
-	file = g_file_new_for_path (path);
-	g_message ("  Adding:'%s'", path);
-	tracker_miner_fs_directory_add (fs, file, TRUE);
-	g_object_unref (file);
-	g_free (path);
-}
-
-static void
-miner_applications_add_directories (TrackerMinerFS *fs)
-{
-#ifdef HAVE_MEEGOTOUCH
-	GFile *file;
-	const gchar *path;
-#endif /* HAVE_MEEGOTOUCH */
-	const gchar * const *xdg_dirs;
-	const gchar *user_data_dir;
-	gint i;
-
-	g_message ("Setting up applications to iterate from XDG system directories");
-
-	/* Add all XDG system and local dirs */
-	xdg_dirs = g_get_system_data_dirs ();
-
-	for (i = 0; xdg_dirs[i]; i++) {
-		miner_applications_basedir_add (fs, xdg_dirs[i]);
-	}
-
-	g_message ("Setting up applications to iterate from XDG user directories");
-
-	user_data_dir = g_get_user_data_dir ();
-	if (user_data_dir) {
-		miner_applications_basedir_add (fs, user_data_dir);
-	}
-
-#ifdef HAVE_MEEGOTOUCH
-	/* NOTE: We don't use miner_applications_basedir_add() for
-	 * this location because it is unique to MeeGoTouch.
-	 */
-	path = "/usr/lib/duicontrolpanel/";
-
-	g_message ("Setting up applications to iterate from MeegoTouch directories");
-	g_message ("  Adding:'%s'", path);
-
-	file = g_file_new_for_path (path);
-	tracker_miner_fs_directory_add (fs, file, TRUE);
-	g_object_unref (file);
-#endif /* HAVE_MEEGOTOUCH */
-}
-
-static void
-tracker_locale_notify_cb (TrackerLocaleID id,
-                          gpointer        user_data)
-{
-	TrackerMiner *miner = user_data;
-
-	if (tracker_miner_applications_detect_locale_changed (miner)) {
-		tracker_miner_fs_set_mtime_checking (TRACKER_MINER_FS (miner), TRUE);
-
-		miner_applications_add_directories (TRACKER_MINER_FS (miner));
-	}
-}
-
-static void
-miner_finished_cb (TrackerMinerFS *fs,
-                   gdouble         seconds_elapsed,
-                   guint           total_directories_found,
-                   guint           total_directories_ignored,
-                   guint           total_files_found,
-                   guint           total_files_ignored,
-                   gpointer        user_data)
-{
-	/* Update locale file if necessary */
-	if (tracker_miner_applications_locale_changed ()) {
-		tracker_miner_applications_locale_set_current ();
-	}
-}
-
 static gboolean
 miner_applications_initable_init (GInitable     *initable,
                                   GCancellable  *cancellable,
                                   GError       **error)
 {
 	TrackerMinerFS *fs;
-	TrackerMinerApplications *app;
+	GFile *file;
 	GError *inner_error = NULL;
 
 	fs = TRACKER_MINER_FS (initable);
-	app = TRACKER_MINER_APPLICATIONS (initable);
 
 	/* Chain up parent's initable callback before calling child's one */
 	if (!miner_applications_initable_parent_iface->init (initable, cancellable, &inner_error)) {
@@ -218,20 +123,22 @@ miner_applications_initable_init (GInitable     *initable,
 		return FALSE;
 	}
 
-	g_signal_connect (fs, "finished",
-	                  G_CALLBACK (miner_finished_cb),
-	                  NULL);
+	file = g_file_new_for_path ("/usr/share/applications/");
+	tracker_miner_fs_directory_add (fs, file, TRUE);
+	g_object_unref (file);
 
-	miner_applications_add_directories (fs);
+	file = g_file_new_for_path ("/usr/share/desktop-directories/");
+	tracker_miner_fs_directory_add (fs, file, TRUE);
+	g_object_unref (file);
 
 #ifdef HAVE_MEEGOTOUCH
+	file = g_file_new_for_path ("/usr/lib/duicontrolpanel/");
+	tracker_miner_fs_directory_add (fs, file, TRUE);
+	g_object_unref (file);
 	tracker_miner_applications_meego_init ();
 #endif /* HAVE_MEEGOTOUCH */
 
-	app->locale_notification_id = tracker_locale_notify_add (TRACKER_LOCALE_LANGUAGE,
-	                                                         tracker_locale_notify_cb,
-	                                                         app,
-	                                                         NULL);
+	/* FIXME: Check XDG_DATA_DIRS and also process applications in there */
 
 	return TRUE;
 }
@@ -239,12 +146,6 @@ miner_applications_initable_init (GInitable     *initable,
 static void
 miner_applications_finalize (GObject *object)
 {
-	TrackerMinerApplications *app;
-
-	app = TRACKER_MINER_APPLICATIONS (object);
-
-	tracker_locale_notify_remove (app->locale_notification_id);
-
 #ifdef HAVE_MEEGOTOUCH
 	tracker_miner_applications_meego_shutdown ();
 #endif /* HAVE_MEEGOTOUCH */
@@ -492,15 +393,12 @@ process_desktop_file (ProcessApplicationData  *data,
 		tracker_sparql_builder_object (sparql, "nfo:SoftwareCategory");
 
 		if (icon) {
-			gchar *escaped_icon;
 			gchar *icon_uri;
 
 			/* Sanitize icon */
 			g_strstrip (icon);
 
-			escaped_icon = g_uri_escape_string (icon, G_URI_RESERVED_CHARS_ALLOWED_IN_PATH, FALSE);
-
-			icon_uri = g_strdup_printf (THEME_ICON_URN_PREFIX "%s", escaped_icon);
+			icon_uri = g_strdup_printf (THEME_ICON_URN_PREFIX "%s", icon);
 
 			tracker_sparql_builder_subject_iri (sparql, icon_uri);
 			tracker_sparql_builder_predicate (sparql, "a");
@@ -511,7 +409,6 @@ process_desktop_file (ProcessApplicationData  *data,
 			tracker_sparql_builder_object_iri (sparql, icon_uri);
 
 			g_free (icon_uri);
-			g_free (escaped_icon);
 			g_free (icon);
 		}
 
@@ -532,30 +429,6 @@ process_desktop_file (ProcessApplicationData  *data,
 
 		tracker_sparql_builder_predicate (sparql, "nie:dataSource");
 		tracker_sparql_builder_object_iri (sparql, APPLICATION_DATASOURCE_URN);
-	} else if (name && g_ascii_strcasecmp (type, "Link") == 0) {
-		gchar *url = g_key_file_get_string (key_file, GROUP_DESKTOP_ENTRY, "URL", NULL);
-
-		if (url) {
-			uri = g_file_get_uri (data->file);
-			tracker_sparql_builder_insert_silent_open (sparql, TRACKER_MINER_FS_GRAPH_URN);
-
-			tracker_sparql_builder_subject_iri (sparql, uri);
-			tracker_sparql_builder_predicate (sparql, "a");
-			tracker_sparql_builder_object (sparql, "nfo:Bookmark");
-
-			tracker_sparql_builder_predicate (sparql, "nfo:bookmarks");
-			tracker_sparql_builder_object_iri (sparql, url);
-
-			tracker_sparql_builder_predicate (sparql, "nie:dataSource");
-			tracker_sparql_builder_object_iri (sparql, APPLICATION_DATASOURCE_URN);
-
-			is_software = FALSE;
-
-			g_free (url);
-		} else {
-			g_warning ("Invalid desktop file: '%s'", uri);
-			g_warning ("  Type 'Link' requires a URL");
-		}
 #ifdef HAVE_MEEGOTOUCH
 	} else if (name && g_ascii_strcasecmp (type, "ControlPanelApplet") == 0) {
 		/* Special case control panel applets */
@@ -693,15 +566,12 @@ process_desktop_file (ProcessApplicationData  *data,
 			icon = g_key_file_get_string (key_file, GROUP_DESKTOP_ENTRY, "Icon", NULL);
 
 			if (icon) {
-				gchar *escaped_icon;
 				gchar *icon_uri;
 
 				/* Sanitize icon */
 				g_strstrip (icon);
 
-				escaped_icon = g_uri_escape_string (icon, G_URI_RESERVED_CHARS_ALLOWED_IN_PATH, FALSE);
-
-				icon_uri = g_strdup_printf (THEME_ICON_URN_PREFIX "%s", escaped_icon);
+				icon_uri = g_strdup_printf (THEME_ICON_URN_PREFIX "%s", icon);
 
 				tracker_sparql_builder_subject_iri (sparql, icon_uri);
 				tracker_sparql_builder_predicate (sparql, "a");
@@ -712,7 +582,6 @@ process_desktop_file (ProcessApplicationData  *data,
 				tracker_sparql_builder_object_iri (sparql, icon_uri);
 
 				g_free (icon_uri);
-				g_free (escaped_icon);
 				g_free (icon);
 			}
 		}
@@ -838,22 +707,10 @@ process_file_cb (GObject      *object,
 
 	if (g_file_info_get_file_type (file_info) == G_FILE_TYPE_DIRECTORY) {
 		process_directory (data, file_info, &error);
+	} else if (data->key_file) {
+		process_desktop_file (data, file_info, &error);
 	} else {
-		data->key_file = get_desktop_key_file (file, &data->type, &error);
-		if (!data->key_file) {
-			gchar *uri;
-
-			uri = g_file_get_uri (file);
-			g_warning ("Couldn't properly parse desktop file '%s': '%s'",
-			           uri,
-			           error ? error->message : "unknown error");
-			g_free (uri);
-			g_clear_error (&error);
-
-			error = g_error_new_literal (miner_applications_error_quark, 0, "File is not a key file");
-		} else {
-			process_desktop_file (data, file_info, &error);
-		}
+		error = g_error_new_literal (miner_applications_error_quark, 0, "File is not a key file");
 	}
 
 	tracker_miner_fs_file_notify (TRACKER_MINER_FS (data->miner), data->file, error);
@@ -875,13 +732,19 @@ miner_applications_process_file (TrackerMinerFS       *fs,
                                  GCancellable         *cancellable)
 {
 	ProcessApplicationData *data;
+	GKeyFile *key_file;
 	const gchar *attrs;
+	gchar *type;
+
+	key_file = get_desktop_key_file (file, &type, NULL);
 
 	data = g_slice_new0 (ProcessApplicationData);
 	data->miner = g_object_ref (fs);
 	data->sparql = g_object_ref (sparql);
 	data->file = g_object_ref (file);
 	data->cancellable = g_object_ref (cancellable);
+	data->key_file = key_file;
+	data->type = type;
 
 	attrs = G_FILE_ATTRIBUTE_TIME_MODIFIED ","
 		G_FILE_ATTRIBUTE_STANDARD_TYPE;
@@ -1027,5 +890,6 @@ tracker_miner_applications_new (GError **error)
 	                       "name", "Applications",
 	                       "processing-pool-wait-limit", 10,
 	                       "processing-pool-ready-limit", 100,
+	                       "processing-pool-requests-limit", 10,
 	                       NULL);
 }
