@@ -93,6 +93,7 @@ static const gchar *introspection_xml =
 	"      <arg type='s' name='mime' direction='in' />"
 	"      <arg type='s' name='preupdate' direction='out' />"
 	"      <arg type='s' name='embedded' direction='out' />"
+	"      <arg type='s' name='where' direction='out' />"
 	"    </method>"
 	"    <method name='GetMetadataFast'>"
 	"      <arg type='s' name='uri' direction='in' />"
@@ -287,7 +288,7 @@ cancel_tasks_in_file (TrackerController *controller,
 				 */
 				g_message ("Cancelled task ('%s') is currently being processed, quitting",
 				           data->uri);
-				_exit (0);
+				g_main_loop_quit (priv->main_loop);
 			} else {
 				g_message ("Cancelling not yet processed task ('%s')",
 				           data->uri);
@@ -426,12 +427,13 @@ get_metadata_cb (GObject      *object,
 			}
 
 			g_dbus_method_invocation_return_value (data->invocation,
-			                                       g_variant_new ("(ss)",
+			                                       g_variant_new ("(sss)",
 			                                                      preupdate_str ? preupdate_str : "",
-			                                                      tracker_sparql_builder_get_result (info->statements)));
+			                                                      tracker_sparql_builder_get_result (info->statements),
+			                                                      info->where ? info->where : ""));
 		} else {
 			g_dbus_method_invocation_return_value (data->invocation,
-			                                       g_variant_new ("(ss)", "", ""));
+			                                       g_variant_new ("(sss)", "", "", ""));
 		}
 
 		tracker_dbus_request_end (data->request, NULL);
@@ -571,6 +573,20 @@ get_metadata_fast_cb (GObject      *object,
 				                               NULL,
 				                               &error);
 			}
+
+			if (!error && info->where) {
+				g_data_output_stream_put_string (data_output_stream,
+				                                 info->where,
+				                                 NULL,
+				                                 &error);
+			}
+
+			if (!error) {
+				g_data_output_stream_put_byte (data_output_stream,
+				                               0,
+				                               NULL,
+				                               &error);
+			}
 		}
 
 		g_object_unref (data_output_stream);
@@ -638,12 +654,7 @@ handle_method_call_get_metadata_fast (TrackerController     *controller,
 
 		fd_list = g_dbus_message_get_unix_fd_list (method_message);
 
-		if (fd_list == NULL) {
-			error = g_error_new_literal (TRACKER_DBUS_ERROR, 0,
-				                     "No FD list");
-		}
-
-		if (fd_list && (fd = g_unix_fd_list_get (fd_list, index_fd, &error)) != -1) {
+		if ((fd = g_unix_fd_list_get (fd_list, index_fd, &error)) != -1) {
 			data = metadata_data_new (controller, uri, mime, invocation, request);
 			data->fd = fd;
 
