@@ -24,13 +24,6 @@
 #define _GNU_SOURCE
 #endif
 
-#include <errno.h>
-#include <fcntl.h>
-#include <string.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <unistd.h>
-
 #include <gif_lib.h>
 
 #include <libtracker-common/tracker-common.h>
@@ -52,18 +45,9 @@ typedef struct {
 	gchar *comment;
 } GifData;
 
-static void extract_gif (const gchar          *filename,
-                         TrackerSparqlBuilder *preupdate,
-                         TrackerSparqlBuilder *metadata);
-
-static TrackerExtractData data[] = {
-	{ "image/gif", extract_gif },
-	{ NULL, NULL }
-};
-
 typedef struct {
-	unsigned int   byteCount;
-	char          *bytes;
+    unsigned int   byteCount;
+    char          *bytes;
 } ExtBlock;
 
 
@@ -87,6 +71,7 @@ ext_block_append(ExtBlock *extBlock,
 static void
 read_metadata (TrackerSparqlBuilder *preupdate,
                TrackerSparqlBuilder *metadata,
+               GString              *where,
 	       GifFileType          *gifFile,
                const gchar          *uri)
 {
@@ -100,7 +85,6 @@ read_metadata (TrackerSparqlBuilder *preupdate,
 	MergeData md = { 0 };
 	GifData   gd = { 0 };
 	TrackerXmpData *xd = NULL;
-	GString *where = NULL;
 
 	do {
 		GifByteType *ExtData;
@@ -159,8 +143,8 @@ read_metadata (TrackerSparqlBuilder *preupdate,
 				}
 
 				xd = tracker_xmp_new (extBlock.bytes,
-				                      extBlock.byteCount-XMP_MAGIC_TRAILER_LENGTH,
-				                      uri);
+						      extBlock.byteCount-XMP_MAGIC_TRAILER_LENGTH,
+						      uri);
 
 				g_free (extBlock.bytes);
 			} else
@@ -357,10 +341,6 @@ read_metadata (TrackerSparqlBuilder *preupdate,
 		tracker_keywords_parse (keywords, xd->subject);
 	}
 
-        if (xd->regions) {
-                tracker_xmp_apply_regions (preupdate, metadata, NULL, xd);
-        }
-
 	for (i = 0; i < keywords->len; i++) {
 		gchar *p, *escaped, *var;
 
@@ -383,10 +363,6 @@ read_metadata (TrackerSparqlBuilder *preupdate,
 		tracker_sparql_builder_predicate (metadata, "nao:hasTag");
 		tracker_sparql_builder_object_variable (metadata, var);
 
-		if (where == NULL) {
-			where = g_string_new ("} } WHERE { {\n");
-		}
-
 		g_string_append_printf (where, "?%s a nao:Tag ; nao:prefLabel \"%s\" .\n", var, escaped);
 
 		g_free (var);
@@ -446,8 +422,8 @@ read_metadata (TrackerSparqlBuilder *preupdate,
 		tracker_sparql_builder_object_unvalidated (metadata, xd->coverage);
 	}
 
-	if (xd->address || xd->state || xd->country || xd->city ||
-	    xd->gps_altitude || xd->gps_latitude || xd-> gps_longitude) {
+	if (xd->address || xd->country || xd->city) {
+		gchar *addruri;
 
 		tracker_sparql_builder_predicate (metadata, "slo:location");
 
@@ -455,65 +431,43 @@ read_metadata (TrackerSparqlBuilder *preupdate,
 		tracker_sparql_builder_predicate (metadata, "a");
 		tracker_sparql_builder_object (metadata, "slo:GeoLocation");
 
-		if (xd->address || xd->state || xd->country || xd->city)  {
-			gchar *addruri;
-			addruri = tracker_sparql_get_uuid_urn ();
+		addruri = tracker_sparql_get_uuid_urn ();
 
-			tracker_sparql_builder_predicate (metadata, "slo:postalAddress");
-			tracker_sparql_builder_object_iri (metadata, addruri);			
-
-			tracker_sparql_builder_insert_open (preupdate, NULL);
-			tracker_sparql_builder_subject_iri (preupdate, addruri);
-
-			g_free (addruri);
-
-			tracker_sparql_builder_predicate (preupdate, "a");
-			tracker_sparql_builder_object (preupdate, "nco:PostalAddress");
-
-			if (xd->address) {
-				tracker_sparql_builder_predicate (preupdate, "nco:streetAddress");
-				tracker_sparql_builder_object_unvalidated (preupdate, xd->address);
-			}
-
-			if (xd->state) {
-				tracker_sparql_builder_predicate (preupdate, "nco:region");
-				tracker_sparql_builder_object_unvalidated (preupdate, xd->state);
-			}
-
-			if (xd->city) {
-				tracker_sparql_builder_predicate (preupdate, "nco:locality");
-				tracker_sparql_builder_object_unvalidated (preupdate, xd->city);
-			}
-
-			if (xd->country) {
-				tracker_sparql_builder_predicate (preupdate, "nco:country");
-				tracker_sparql_builder_object_unvalidated (preupdate, xd->country);
-			}
-
-			tracker_sparql_builder_insert_close (preupdate);
-		}
-
-		if (xd->gps_altitude) {
-			tracker_sparql_builder_predicate (metadata, "slo:altitude");
-			tracker_sparql_builder_object_unvalidated (metadata, xd->gps_altitude);
-		}
-
-		if (xd->gps_latitude) {
-			tracker_sparql_builder_predicate (metadata, "slo:latitude");
-			tracker_sparql_builder_object_unvalidated (metadata, xd->gps_latitude);
-		}
-
-		if (xd->gps_longitude) {
-			tracker_sparql_builder_predicate (metadata, "slo:longitude");
-			tracker_sparql_builder_object_unvalidated (metadata, xd->gps_longitude);
-		}
+		tracker_sparql_builder_predicate (metadata, "slo:postalAddress");
+		tracker_sparql_builder_object_iri (metadata, addruri);
 
 		tracker_sparql_builder_object_blank_close (metadata); /* GeoLocation */
-	}
 
-	if (xd->gps_direction) {
-		tracker_sparql_builder_predicate (metadata, "nfo:heading");
-		tracker_sparql_builder_object_unvalidated (metadata, xd->gps_direction);
+		tracker_sparql_builder_insert_open (preupdate, NULL);
+		tracker_sparql_builder_subject_iri (preupdate, addruri);
+
+		g_free (addruri);
+
+		tracker_sparql_builder_predicate (preupdate, "a");
+		tracker_sparql_builder_object (preupdate, "nco:PostalAddress");
+
+		if (xd->address) {
+			tracker_sparql_builder_predicate (preupdate, "nco:streetAddress");
+			tracker_sparql_builder_object_unvalidated (preupdate, xd->address);
+		}
+
+		if (xd->state) {
+			tracker_sparql_builder_predicate (preupdate, "nco:region");
+			tracker_sparql_builder_object_unvalidated (preupdate, xd->state);
+		}
+
+		if (xd->city) {
+			tracker_sparql_builder_predicate (preupdate, "nco:locality");
+			tracker_sparql_builder_object_unvalidated (preupdate, xd->city);
+		}
+
+		if (xd->country) {
+			tracker_sparql_builder_predicate (preupdate, "nco:country");
+			tracker_sparql_builder_object_unvalidated (preupdate, xd->country);
+		}
+
+		tracker_sparql_builder_insert_close (preupdate);
+
 	}
 
 	if (gd.width) {
@@ -534,50 +488,32 @@ read_metadata (TrackerSparqlBuilder *preupdate,
 		g_free (gd.comment);
 	}
 
-	if (where != NULL) {
-		tracker_sparql_builder_append (metadata, where->str);
-		g_string_free (where, TRUE);
-	}
-
 	tracker_xmp_free (xd);
 }
 
 
-static void
-extract_gif (const gchar          *uri,
-             TrackerSparqlBuilder *preupdate,
-             TrackerSparqlBuilder *metadata)
+G_MODULE_EXPORT gboolean
+tracker_extract_get_metadata (const gchar          *uri,
+			      const gchar          *mimetype,
+			      TrackerSparqlBuilder *preupdate,
+			      TrackerSparqlBuilder *metadata,
+			      GString              *where)
 {
 	goffset size;
 	GifFileType *gifFile = NULL;
 	gchar *filename;
-	int fd;
 
 	filename = g_filename_from_uri (uri, NULL, NULL);
 	size = tracker_file_get_size (filename);
 
 	if (size < 64) {
 		g_free (filename);
-		return;
+		return FALSE;
 	}
 
-	fd = g_open (filename, O_RDONLY | O_NOATIME, 0);
-	if (fd == -1 && errno == EPERM) {
-		fd = g_open (filename, O_RDONLY, 0);
-	}
-
-	if (fd == -1) {
-		g_warning ("Could not open gif file '%s': %s\n",
-		           filename,
-		           g_strerror (errno));
-		g_free (filename);
-		return;
-	}	
-
-	if ((gifFile = DGifOpenFileHandle (fd)) == NULL) {
+	if ((gifFile = DGifOpenFileName (filename)) == NULL) {
 		PrintGifError ();
-		close (fd);
-		return;
+		return FALSE;
 	}
 
 	g_free (filename);
@@ -586,17 +522,11 @@ extract_gif (const gchar          *uri,
 	tracker_sparql_builder_object (metadata, "nfo:Image");
 	tracker_sparql_builder_object (metadata, "nmm:Photo");
 
-	read_metadata (preupdate, metadata, gifFile, uri);
+	read_metadata (preupdate, metadata, where, gifFile, uri);
 
 	if (DGifCloseFile (gifFile) != GIF_OK) {
 		PrintGifError ();
 	}
 
-	close (fd);
-}
-
-TrackerExtractData *
-tracker_extract_get_data (void)
-{
-	return data;
+	return TRUE;
 }
