@@ -183,10 +183,6 @@ typedef struct {
 	id3v2tag id3v24;
 } MP3Data;
 
-static void extract_mp3 (const gchar           *uri,
-                         TrackerSparqlBuilder  *preupdate,
-                         TrackerSparqlBuilder  *metadata);
-
 enum {
 	MPEG_ERR,
 	MPEG_V1,
@@ -441,14 +437,6 @@ static gint spf_table[6] = {
 	48, 144, 144, 48, 144,  72
 };
 
-static TrackerExtractData extract_data[] = {
-	{ "audio/mpeg", extract_mp3 },
-	{ "audio/x-mp3", extract_mp3 },
-	{ NULL, NULL }
-};
-
-
-
 static void
 id3tag_free (id3tag *tags)
 {
@@ -482,40 +470,6 @@ id3v2tag_free (id3v2tag *tags)
 	g_free (tags->title3);
 }
 
-static gboolean
-guess_dlna_profile (gint          bitrate,
-                    gint          frequency,
-                    gint          mpeg_version,
-                    gint          layer_version,
-                    gint          n_channels,
-                    const gchar **dlna_profile,
-                    const gchar **dlna_mimetype)
-{
-	if (mpeg_version == MPEG_V1 &&
-	    layer_version == LAYER_3 &&
-	    (bitrate >= 32000 && bitrate <= 320000) &&
-	    (n_channels == 1 || n_channels == 2) &&
-	    (frequency == freq_table[0][0] ||
-	     frequency == freq_table[1][0] ||
-	     frequency == freq_table[2][0])) {
-		*dlna_profile = "MP3";
-		*dlna_mimetype = "audio/mpeg";
-		return TRUE;
-	}
-
-	if ((bitrate >= 8000 && bitrate <= 320000) &&
-	    (mpeg_version == MPEG_V1 || mpeg_version == MPEG_V2) &&
-	    (frequency == freq_table[0][0] || frequency == freq_table[0][1] ||
-	     frequency == freq_table[1][0] || frequency == freq_table[1][1] ||
-	     frequency == freq_table[2][0] || frequency == freq_table[2][1])) {
-		*dlna_profile = "MP3X";
-		*dlna_mimetype = "audio/mpeg";
-		return TRUE;
-	}
-
-	return FALSE;
-}
-
 static char *
 read_id3v1_buffer (int     fd,
                    goffset size)
@@ -851,7 +805,6 @@ mp3_parse_header (const gchar          *data,
                   TrackerSparqlBuilder *metadata,
                   MP3Data              *filedata)
 {
-	const gchar *dlna_profile, *dlna_mimetype;
 	guint header;
 	gchar mpeg_ver = 0;
 	gchar layer_ver = 0;
@@ -866,7 +819,6 @@ mp3_parse_header (const gchar          *data,
 	guint frame_size;
 	guint frames = 0;
 	size_t pos = 0;
-	gint n_channels;
 
 	pos = seek_pos;
 
@@ -968,10 +920,12 @@ mp3_parse_header (const gchar          *data,
 	tracker_sparql_builder_predicate (metadata, "nfo:codec");
 	tracker_sparql_builder_object_string (metadata, "MPEG");
 
-	n_channels = ((header & ch_mask) == ch_mask) ? 1 : 2;
-
 	tracker_sparql_builder_predicate (metadata, "nfo:channels");
-	tracker_sparql_builder_object_int64 (metadata, n_channels);
+	if ((header & ch_mask) == ch_mask) {
+		tracker_sparql_builder_object_int64 (metadata, 1);
+	} else {
+		tracker_sparql_builder_object_int64 (metadata, 2);
+	}
 
 	avg_bps /= frames;
 
@@ -992,15 +946,6 @@ mp3_parse_header (const gchar          *data,
 	tracker_sparql_builder_predicate (metadata, "nfo:averageBitrate");
 	tracker_sparql_builder_object_int64 (metadata, avg_bps*1000);
 
-	if (guess_dlna_profile (bitrate, sample_rate,
-	                        mpeg_ver, layer_ver, n_channels,
-	                        &dlna_profile, &dlna_mimetype)) {
-		tracker_sparql_builder_predicate (metadata, "nmm:dlnaProfile");
-		tracker_sparql_builder_object_string (metadata, dlna_profile);
-		tracker_sparql_builder_predicate (metadata, "nmm:dlnaMime");
-		tracker_sparql_builder_object_string (metadata, dlna_mimetype);
-	}
-
 	return TRUE;
 }
 
@@ -1059,16 +1004,8 @@ id3v2_strlen (const gchar  encoding,
 	switch (encoding) {
 	case 0x01:
 	case 0x02:
-		
 		/* UTF-16, string terminated by two NUL bytes */
-		pos = memmem (text, len, "\0\0\0", 3);
-
-		if (pos == NULL) {
-			pos = memmem (text, len, "\0\0", 2);
-		} else {
-			pos++;
-		}
-
+		pos = memmem (text, len, "\0\0", 2);
 		if (pos != NULL) {
 			return pos - text;
 		} else {
@@ -1082,8 +1019,7 @@ id3v2_strlen (const gchar  encoding,
 static gchar *
 id3v24_text_to_utf8 (const gchar  encoding,
                      const gchar *text,
-                     gssize       len,
-                     id3tag      *info)
+                     gssize       len)
 {
 	/* This byte describes the encoding
 	 * try to convert strings to UTF-8
@@ -1099,7 +1035,7 @@ id3v24_text_to_utf8 (const gchar  encoding,
 		return convert_to_encoding (text,
 		                            len,
 		                            "UTF-8",
-		                            info->encoding ? info->encoding : "Windows-1252",
+		                            "Windows-1252",
 		                            NULL, NULL, NULL);
 	case 0x01 :
 		return convert_to_encoding (text,
@@ -1124,7 +1060,7 @@ id3v24_text_to_utf8 (const gchar  encoding,
 		return convert_to_encoding (text,
 		                            len,
 		                            "UTF-8",
-		                            info->encoding ? info->encoding : "Windows-1252",
+		                            "Windows-1252",
 		                            NULL, NULL, NULL);
 	}
 }
@@ -1132,8 +1068,7 @@ id3v24_text_to_utf8 (const gchar  encoding,
 static gchar *
 id3v2_text_to_utf8 (const gchar  encoding,
                     const gchar *text,
-                    gssize       len,
-                    id3tag      *info)
+                    gssize       len)
 {
 	/* This byte describes the encoding
 	 * try to convert strings to UTF-8
@@ -1149,7 +1084,7 @@ id3v2_text_to_utf8 (const gchar  encoding,
 		return convert_to_encoding (text,
 		                            len,
 		                            "UTF-8",
-		                            info->encoding ? info->encoding : "Windows-1252",
+		                            "Windows-1252",
 		                            NULL, NULL, NULL);
 	case 0x01 :
 		/* return g_convert (text, */
@@ -1167,7 +1102,7 @@ id3v2_text_to_utf8 (const gchar  encoding,
 		return convert_to_encoding (text,
 		                            len,
 		                            "UTF-8",
-		                            info->encoding ? info->encoding : "Windows-1252",
+		                            "Windows-1252",
 		                            NULL, NULL, NULL);
 	}
 }
@@ -1285,7 +1220,7 @@ get_id3v24_tags (id3v24frame           frame,
 		offset        = 4 + text_desc_len + id3v2_nul_size (text_encode);
 		text          = &data[pos + offset]; /* <full text string according to encoding> */
 
-		word = id3v24_text_to_utf8 (text_encode, text, csize - offset, info);
+		word = id3v24_text_to_utf8 (text_encode, text, csize - offset);
 
 		if (!tracker_is_empty_string (word)) {
 			g_strstrip (word);
@@ -1301,7 +1236,7 @@ get_id3v24_tags (id3v24frame           frame,
 		gchar *word;
 
 		/* text frames */
-		word = id3v24_text_to_utf8 (data[pos], &data[pos + 1], csize - 1, info);
+		word = id3v24_text_to_utf8 (data[pos], &data[pos + 1], csize - 1);
 		if (!tracker_is_empty_string (word)) {
 			g_strstrip (word);
 		}
@@ -1471,7 +1406,7 @@ get_id3v23_tags (id3v24frame           frame,
 		offset        = 4 + text_desc_len + id3v2_nul_size (text_encode);
 		text          = &data[pos + offset]; /* <full text string according to encoding> */
 
-		word = id3v2_text_to_utf8 (text_encode, text, csize - offset, info);
+		word = id3v2_text_to_utf8 (text_encode, text, csize - offset);
 
 		if (!tracker_is_empty_string (word)) {
 			g_strstrip (word);
@@ -1488,7 +1423,7 @@ get_id3v23_tags (id3v24frame           frame,
 		gchar *word;
 
 		/* text frames */
-		word = id3v2_text_to_utf8 (data[pos], &data[pos + 1], csize - 1, info);
+		word = id3v2_text_to_utf8 (data[pos], &data[pos + 1], csize - 1);
 
 		if (!tracker_is_empty_string (word)) {
 			g_strstrip (word);
@@ -1634,7 +1569,7 @@ get_id3v20_tags (id3v2frame            frame,
 		/* text frames */
 		gchar *word;
 
-		word = id3v2_text_to_utf8 (data[pos], &data[pos + 1], csize - 1, info);
+		word = id3v2_text_to_utf8 (data[pos], &data[pos + 1], csize - 1);
 		if (!tracker_is_empty_string (word)) {
 			g_strstrip (word);
 		}
@@ -2073,10 +2008,12 @@ parse_id3v2 (const gchar          *data,
 	return offset;
 }
 
-static void
-extract_mp3 (const gchar          *uri,
-             TrackerSparqlBuilder *preupdate,
-             TrackerSparqlBuilder *metadata)
+G_MODULE_EXPORT gboolean
+tracker_extract_get_metadata (const gchar          *uri,
+                              const gchar          *mimetype,
+                              TrackerSparqlBuilder *preupdate,
+                              TrackerSparqlBuilder *metadata,
+                              GString              *where)
 {
 	gchar *filename;
 	int fd;
@@ -2093,7 +2030,7 @@ extract_mp3 (const gchar          *uri,
 
 	if (size == 0) {
 		g_free (filename);
-		return;
+		return FALSE;
 	}
 
 	md.size = size;
@@ -2104,18 +2041,18 @@ extract_mp3 (const gchar          *uri,
 	 * without as a last resort. This can happen due to
 	 * permissions.
 	 */
-	fd = g_open (filename, O_RDONLY | O_NOATIME);
-	if (fd == -1 && errno == EPERM) {
-		fd = g_open (filename, O_RDONLY);
+	fd = open (filename, O_RDONLY | O_NOATIME);
+	if (fd == -1) {
+		fd = open (filename, O_RDONLY);
 
 		if (fd == -1) {
-			return;
+			return FALSE;
 		}
 	}
 #else
 	fd = open (filename, O_RDONLY);
 	if (fd == -1) {
-		return;
+		return FALSE;
 	}
 #endif
 
@@ -2139,7 +2076,7 @@ extract_mp3 (const gchar          *uri,
 
 	if (buffer == NULL || buffer == (void*) -1) {
 		g_free (filename);
-		return;
+		return FALSE;
 	}
 
 	if (!get_id3 (id3v1_buffer, ID3V1_SIZE, &md.id3v1)) {
@@ -2148,21 +2085,6 @@ extract_mp3 (const gchar          *uri,
 
 	g_free (id3v1_buffer);
 
-	if (md.id3v1.encoding != NULL) {
-		gchar *locale;
-
-		locale = tracker_locale_get (TRACKER_LOCALE_LANGUAGE);
-		if (!g_str_has_prefix (locale, "ru") &&
-		    !g_str_has_prefix (locale, "uk")) {
-			/* use guessed encoding for ID3v2 tags only in selected locales
-			   where broken ID3v2 is widespread */
-			g_free (md.id3v1.encoding);
-			md.id3v1.encoding = NULL;
-		}
-		g_free (locale);
-		locale = NULL;
-	}
-
 	/* Get other embedded tags */
 	audio_offset = parse_id3v2 (buffer, buffer_size, &md.id3v1, uri, metadata, &md);
 
@@ -2465,6 +2387,10 @@ extract_mp3 (const gchar          *uri,
 
 	g_free (md.album_uri);
 
+	/* FIXME We use a hardcoded value here for now. In reality there's a second option MP3X */
+	tracker_sparql_builder_predicate (metadata, "nmm:dlnaProfile");
+	tracker_sparql_builder_object_string (metadata, "MP3");
+
 	/* Get mp3 stream info */
 	mp3_parse (buffer, buffer_size, audio_offset, uri, metadata, &md);
 
@@ -2487,11 +2413,7 @@ extract_mp3 (const gchar          *uri,
 #endif
 
 	g_free (filename);
-}
 
-TrackerExtractData *
-tracker_extract_get_data (void)
-{
-	return extract_data;
+	return TRUE;
 }
 
