@@ -97,19 +97,11 @@ static void xml_text_handler_content           (GMarkupParseContext   *context,
                                                 gsize                  text_len,
                                                 gpointer               user_data,
                                                 GError               **error);
-static void extract_oasis                      (const gchar           *filename,
-                                                TrackerSparqlBuilder  *preupdate,
-                                                TrackerSparqlBuilder  *metadata);
 static void extract_oasis_content              (const gchar           *uri,
                                                 gulong                 total_bytes,
                                                 ODTFileType            file_type,
                                                 TrackerSparqlBuilder  *metadata);
 
-static TrackerExtractData extract_data[] = {
-	{ "application/vnd.oasis.opendocument.*", extract_oasis },
-	{ NULL, NULL }
-};
-
 static void
 extract_oasis_content (const gchar          *uri,
                        gulong                total_bytes,
@@ -164,17 +156,16 @@ extract_oasis_content (const gchar          *uri,
 	g_markup_parse_context_free (context);
 }
 
-static void
-extract_oasis (const gchar          *uri,
-               TrackerSparqlBuilder *preupdate,
-               TrackerSparqlBuilder *metadata)
+G_MODULE_EXPORT gboolean
+tracker_extract_get_metadata (const gchar          *uri,
+                              const gchar          *mime_used,
+                              TrackerSparqlBuilder *preupdate,
+                              TrackerSparqlBuilder *metadata,
+                              GString              *where)
 {
 	TrackerConfig *config;
 	ODTMetadataParseInfo info;
 	ODTFileType file_type;
-	GFile *file = NULL;
-	GFileInfo *file_info = NULL;
-	const gchar *mime_used;
 	GMarkupParseContext *context;
 	GMarkupParser parser = {
 		xml_start_element_handler_metadata,
@@ -212,30 +203,6 @@ extract_oasis (const gchar          *uri,
 	tracker_gsf_parse_xml_in_zip (uri, "meta.xml", context, NULL);
 	g_markup_parse_context_free (context);
 
-	/* Next, parse contents */
-	file = g_file_new_for_uri (uri);
-
-	if (!file) {
-		g_warning ("Could not create GFile for URI:'%s'",
-		           uri);
-		return;
-	}
-
-	file_info = g_file_query_info (file,
-	                               G_FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE,
-	                               G_FILE_QUERY_INFO_NONE,
-	                               NULL,
-	                               NULL);
-	g_object_unref (file);
-
-	if (!file_info) {
-		g_warning ("Could not get GFileInfo for URI:'%s'",
-		           uri);
-		return;
-	}
-
-	mime_used = g_file_info_get_content_type (file_info);
-
 	if (g_ascii_strcasecmp (mime_used, "application/vnd.oasis.opendocument.text") == 0) {
 		file_type = FILE_TYPE_ODT;
 	} else if (g_ascii_strcasecmp (mime_used, "application/vnd.oasis.opendocument.presentation") == 0) {
@@ -247,13 +214,13 @@ extract_oasis (const gchar          *uri,
 		file_type = FILE_TYPE_INVALID;
 	}
 
-	g_object_unref (file_info);
-
 	/* Extract content with the given limitations */
 	extract_oasis_content (uri,
 	                       tracker_config_get_max_bytes (config),
 	                       file_type,
 	                       metadata);
+
+	return TRUE;
 }
 
 static void
@@ -325,11 +292,6 @@ xml_text_handler_metadata (GMarkupParseContext  *context,
 	data = user_data;
 	metadata = data->metadata;
 
-	if (text_len == 0) {
-		/* ignore empty values */
-		return;
-	}
-
 	switch (data->current) {
 	case ODT_TAG_TYPE_TITLE:
 		if (data->title_already_set) {
@@ -384,11 +346,9 @@ xml_text_handler_metadata (GMarkupParseContext  *context,
 
 	case ODT_TAG_TYPE_CREATED:
 		date = tracker_date_guess (text);
-		if (date) {
-			tracker_sparql_builder_predicate (metadata, "nie:contentCreated");
-			tracker_sparql_builder_object_unvalidated (metadata, date);
-			g_free (date);
-		}
+		tracker_sparql_builder_predicate (metadata, "nie:contentCreated");
+		tracker_sparql_builder_object_unvalidated (metadata, date);
+		g_free (date);
 		break;
 
 	case ODT_TAG_TYPE_GENERATOR:
@@ -545,9 +505,3 @@ xml_text_handler_content (GMarkupParseContext  *context,
 		break;
 	}
 }
-
-TrackerExtractData *
-tracker_extract_get_data (void)
-{
-	return extract_data;
-}
