@@ -21,25 +21,13 @@
 
 #include "config.h"
 
-#ifndef _GNU_SOURCE
-#define _GNU_SOURCE
-#endif
-
-#include <errno.h>
-#include <fcntl.h>
 #include <string.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <unistd.h>
-#include <sys/mman.h>
 
 #include <glib.h>
-#include <glib/gstdio.h>
 #include <glib/poppler.h>
 
 #include <libtracker-common/tracker-date-time.h>
 #include <libtracker-common/tracker-utils.h>
-#include <libtracker-common/tracker-file-utils.h>
 
 #include <libtracker-extract/tracker-extract.h>
 
@@ -54,15 +42,6 @@ typedef struct {
 	gchar *keywords;
 } PDFData;
 
-static void extract_pdf (const gchar          *uri,
-                         TrackerSparqlBuilder *preupdate,
-                         TrackerSparqlBuilder *metadata);
-
-static TrackerExtractData data[] = {
-	{ "application/pdf", extract_pdf },
-	{ NULL, NULL }
-};
-
 static void
 read_toc (PopplerIndexIter  *index,
           GString          **toc)
@@ -285,10 +264,12 @@ write_pdf_data (PDFData               data,
 	}
 }
 
-static void
-extract_pdf (const gchar          *uri,
-             TrackerSparqlBuilder *preupdate,
-             TrackerSparqlBuilder *metadata)
+G_MODULE_EXPORT gboolean
+tracker_extract_get_metadata (const gchar          *uri,
+                              const gchar          *mimetype,
+                              TrackerSparqlBuilder *preupdate,
+                              TrackerSparqlBuilder *metadata,
+                              GString              *where)
 {
 	TrackerConfig *config;
 	GTime creation_date;
@@ -302,59 +283,11 @@ extract_pdf (const gchar          *uri,
 	guint n_bytes;
 	GPtrArray *keywords;
 	guint i;
-	GString *where = NULL;
-	gchar *filename;
-	int fd;
-	gchar *contents = NULL;
-	gsize len;
-	struct stat st;
 
 	g_type_init ();
 
-	filename = g_filename_from_uri (uri, NULL, NULL);
+	document = poppler_document_new_from_file (uri, NULL, &error);
 
-	fd = g_open (filename, O_RDONLY | O_NOATIME, 0);
-	if (fd == -1 && errno == EPERM) {
-		fd = g_open (filename, O_RDONLY, 0);
-	}
-
-	if (fd == -1) {
-		g_warning ("Could not open pdf file '%s': %s\n",
-		           filename,
-		           g_strerror (errno));
-		g_free (filename);
-		return;
-	}
-
-	if (fstat (fd, &st) == -1) {
-		g_warning ("Could not fstat pdf file '%s': %s\n",
-		           filename,
-		           g_strerror (errno));
-		close (fd);
-		g_free (filename);
-		return;
-	}
-
-	if (st.st_size == 0) {
-		contents = NULL;
-		len = 0;
-	} else {
-		contents = (gchar *) mmap (NULL, st.st_size, PROT_READ, MAP_PRIVATE, fd, 0);
-		if (contents == NULL) {
-			g_warning ("Could not mmap pdf file '%s': %s\n",
-			           filename,
-			           g_strerror (errno));
-			close (fd);
-			g_free (filename);
-			return;
-		}
-		len = st.st_size;
-	}
-
-	g_free (filename);
-
-	document = poppler_document_new_from_data (contents, len, NULL, &error);
-	
 	if (error) {
 		if (error->code == POPPLER_ERROR_ENCRYPTED) {
 			tracker_sparql_builder_predicate (metadata, "a");
@@ -362,23 +295,24 @@ extract_pdf (const gchar          *uri,
 
 			tracker_sparql_builder_predicate (metadata, "nfo:isContentEncrypted");
 			tracker_sparql_builder_object_boolean (metadata, TRUE);
+
+			g_error_free (error);
+			return TRUE;
 		} else {
 			g_warning ("Couldn't create PopplerDocument from uri:'%s', %s",
 			           uri,
 			           error->message ? error->message : "no error given");
-		}
 
-		close (fd);
-		g_error_free (error);
-		return;
+			g_error_free (error);
+			return FALSE;
+		}
 	}
 
 	if (!document) {
 		g_warning ("Could not create PopplerDocument from uri:'%s', "
 		           "NULL returned without an error",
 		           uri);
-		close (fd);
-		return;
+		return FALSE;
 	}
 
 	tracker_sparql_builder_predicate (metadata, "a");
@@ -571,74 +505,52 @@ extract_pdf (const gchar          *uri,
 			tracker_sparql_builder_object (metadata, xd->metering_mode);
 		}
 
-		if (xd->address || xd->state || xd->country || xd->city ||
-		    xd->gps_altitude || xd->gps_latitude || xd-> gps_longitude) {
+		if (xd->address || xd->country || xd->city) {
+			gchar *addruri;
 
 			tracker_sparql_builder_predicate (metadata, "slo:location");
 
-			tracker_sparql_builder_object_blank_open (metadata); /* GeoLocation */
+			tracker_sparql_builder_object_blank_open (metadata);
 			tracker_sparql_builder_predicate (metadata, "a");
-			tracker_sparql_builder_object (metadata, "slo:GeoLocation");
-			
-			if (xd->address || xd->state || xd->country || xd->city)  {
-				gchar *addruri;
-				addruri = tracker_sparql_get_uuid_urn ();
+			tracker_sparql_builder_object (metadata, "slo:GeoLocation"); /* GeoLocation */
 
-				tracker_sparql_builder_predicate (metadata, "slo:postalAddress");
-				tracker_sparql_builder_object_iri (metadata, addruri);			
+			addruri = tracker_sparql_get_uuid_urn ();
 
-				tracker_sparql_builder_insert_open (preupdate, NULL);
-				tracker_sparql_builder_subject_iri (preupdate, addruri);
-
-				g_free (addruri);
-
-				tracker_sparql_builder_predicate (preupdate, "a");
-				tracker_sparql_builder_object (preupdate, "nco:PostalAddress");
-
-				if (xd->address) {
-				        tracker_sparql_builder_predicate (preupdate, "nco:streetAddress");
-				        tracker_sparql_builder_object_unvalidated (preupdate, xd->address);
-				}
-
-				if (xd->state) {
-				        tracker_sparql_builder_predicate (preupdate, "nco:region");
-				        tracker_sparql_builder_object_unvalidated (preupdate, xd->state);
-				}
-
-				if (xd->city) {
-				        tracker_sparql_builder_predicate (preupdate, "nco:locality");
-				        tracker_sparql_builder_object_unvalidated (preupdate, xd->city);
-				}
-
-				if (xd->country) {
-				        tracker_sparql_builder_predicate (preupdate, "nco:country");
-				        tracker_sparql_builder_object_unvalidated (preupdate, xd->country);
-				}
-
-				tracker_sparql_builder_insert_close (preupdate);
-			}
-
-			if (xd->gps_altitude) {
-				tracker_sparql_builder_predicate (metadata, "slo:altitude");
-				tracker_sparql_builder_object_unvalidated (metadata, xd->gps_altitude);
-			}
-
-			if (xd->gps_latitude) {
-				tracker_sparql_builder_predicate (metadata, "slo:latitude");
-				tracker_sparql_builder_object_unvalidated (metadata, xd->gps_latitude);
-			}
-
-			if (xd->gps_longitude) {
-				tracker_sparql_builder_predicate (metadata, "slo:longitude");
-				tracker_sparql_builder_object_unvalidated (metadata, xd->gps_longitude);
-			}
+			tracker_sparql_builder_predicate (metadata, "slo:postalAddress");
+			tracker_sparql_builder_object_iri (metadata, addruri);
 
 			tracker_sparql_builder_object_blank_close (metadata); /* GeoLocation */
-		}
 
-                if (xd->regions) {
-	                tracker_xmp_apply_regions (preupdate, metadata, NULL, xd);
-                }
+			tracker_sparql_builder_insert_open (preupdate, NULL);
+			tracker_sparql_builder_subject_iri (preupdate, addruri);
+
+			g_free (addruri);
+
+			tracker_sparql_builder_predicate (preupdate, "a");
+			tracker_sparql_builder_object (preupdate, "nco:PostalAddress");
+
+			if (xd->address) {
+				tracker_sparql_builder_predicate (preupdate, "nco:streetAddress");
+				tracker_sparql_builder_object_unvalidated (preupdate, xd->address);
+			}
+
+			if (xd->state) {
+				tracker_sparql_builder_predicate (preupdate, "nco:region");
+				tracker_sparql_builder_object_unvalidated (preupdate, xd->state);
+			}
+
+			if (xd->city) {
+				tracker_sparql_builder_predicate (preupdate, "nco:locality");
+				tracker_sparql_builder_object_unvalidated (preupdate, xd->city);
+			}
+
+			if (xd->country) {
+				tracker_sparql_builder_predicate (preupdate, "nco:country");
+				tracker_sparql_builder_object_unvalidated (preupdate, xd->country);
+			}
+
+			tracker_sparql_builder_insert_close (preupdate);
+		}
 
 		tracker_xmp_free (xd);
 	} else {
@@ -670,10 +582,6 @@ extract_pdf (const gchar          *uri,
 		tracker_sparql_builder_predicate (metadata, "nao:hasTag");
 		tracker_sparql_builder_object_variable (metadata, var);
 
-		if (where == NULL) {
-			where = g_string_new ("} } WHERE { {\n");
-		}
-
 		g_string_append_printf (where, "?%s a nao:Tag ; nao:prefLabel \"%s\" .\n", var, escaped);
 
 		g_free (var);
@@ -697,11 +605,6 @@ extract_pdf (const gchar          *uri,
 
 	read_outline (document, metadata);
 
-	if (where != NULL) {
-		tracker_sparql_builder_append (metadata, where->str);
-		g_string_free (where, TRUE);
-	}
-
 	g_free (xml);
 	g_free (pd.keywords);
 	g_free (pd.title);
@@ -712,15 +615,5 @@ extract_pdf (const gchar          *uri,
 
 	g_object_unref (document);
 
-	if (contents) {
-		munmap (contents, len);
-	}
-
-	close (fd);
-}
-
-TrackerExtractData *
-tracker_extract_get_data (void)
-{
-	return data;
+	return TRUE;
 }
