@@ -20,17 +20,6 @@
 
 #include "config.h"
 
-#ifndef _GNU_SOURCE
-#define _GNU_SOURCE
-#endif
-
-#include <errno.h>
-#include <fcntl.h>
-#include <string.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <unistd.h>
-
 #include <glib/gstdio.h>
 
 #include <tiffio.h>
@@ -71,10 +60,6 @@ typedef struct {
 	const gchar *state;
 	const gchar *address;
 	const gchar *country;
-	const gchar *gps_altitude;
-	const gchar *gps_latitude;
-	const gchar *gps_longitude;
-	const gchar *gps_direction;
 } MergeData;
 
 typedef struct {
@@ -90,15 +75,6 @@ typedef struct {
 	gchar *orientation;
 } TiffData;
 
-static void extract_tiff (const gchar          *filename,
-                          TrackerSparqlBuilder *preupdate,
-                          TrackerSparqlBuilder *metadata);
-
-static TrackerExtractData extract_data[] = {
-	{ "image/tiff", extract_tiff },
-	{ NULL, NULL }
-};
-
 static void
 tiff_data_free (TiffData *tags)
 {
@@ -263,10 +239,12 @@ tag_to_string (TIFF    *image,
 	return NULL;
 }
 
-static void
-extract_tiff (const gchar          *uri,
-              TrackerSparqlBuilder *preupdate,
-              TrackerSparqlBuilder *metadata)
+G_MODULE_EXPORT gboolean
+tracker_extract_get_metadata (const gchar          *uri,
+                              const gchar          *mimetype,
+                              TrackerSparqlBuilder *preupdate,
+                              TrackerSparqlBuilder *metadata,
+                              GString              *where)
 {
 	TIFF *image;
 	TrackerXmpData *xd = NULL;
@@ -279,8 +257,6 @@ extract_tiff (const gchar          *uri,
 	glong exif_offset;
 	GPtrArray *keywords;
 	guint i;
-	GString *where = NULL;
-	int fd;
 
 #ifdef HAVE_LIBIPTCDATA
 	gchar *iptc_offset;
@@ -294,24 +270,10 @@ extract_tiff (const gchar          *uri,
 
 	filename = g_filename_from_uri (uri, NULL, NULL);
 
-	fd = g_open (filename, O_RDONLY | O_NOATIME, 0);
-	if (fd == -1 && errno == EPERM) {
-		fd = g_open (filename, O_RDONLY, 0);
-	}
-
-	if (fd == -1) {
-		g_warning ("Could not open tiff file '%s': %s\n",
-		           filename,
-		           g_strerror (errno));
-		g_free (filename);
-		return;
-	}	
-
-	if ((image = TIFFFdOpen (fd, filename, "r")) == NULL){
+	if ((image = TIFFOpen (filename, "r")) == NULL){
 		g_warning ("Could not open image:'%s'\n", filename);
 		g_free (filename);
-		close (fd);
-		return;
+		return FALSE;
 	}
 
 	tracker_sparql_builder_predicate (metadata, "a");
@@ -403,12 +365,6 @@ extract_tiff (const gchar          *uri,
 	md.state = tracker_coalesce_strip (2, xd->state, id->state);
 	md.address = tracker_coalesce_strip (2, xd->address, id->sublocation);
 	md.country = tracker_coalesce_strip (2, xd->country, id->country_name);
-
-	/* FIXME We are not handling the altitude ref here for xmp */
-	md.gps_altitude = tracker_coalesce_strip (2, xd->gps_altitude, ed->gps_altitude);
-	md.gps_latitude = tracker_coalesce_strip (2, xd->gps_latitude, ed->gps_latitude);
-	md.gps_longitude = tracker_coalesce_strip (2, xd->gps_longitude, ed->gps_longitude);
-	md.gps_direction = tracker_coalesce_strip (2, xd->gps_direction, ed->gps_direction);
 	md.creator = tracker_coalesce_strip (3, xd->creator, id->byline, id->credit);
 	md.x_dimension = tracker_coalesce_strip (2, td.width, ed->x_dimension);
 	md.y_dimension = tracker_coalesce_strip (2, td.length, ed->y_dimension);
@@ -505,79 +461,51 @@ extract_tiff (const gchar          *uri,
 		tracker_sparql_builder_object_unvalidated (metadata, xd->license);
 	}
 
-        if (xd->regions) {
-	        tracker_xmp_apply_regions (preupdate, metadata, NULL, xd);
-        }
-
-	if (md.address || md.state || md.country || md.city ||
-	    md.gps_altitude || md.gps_latitude || md.gps_longitude) {
+	if (md.city || md.state || md.address || md.country) {
+		gchar *addruri;
 
 		tracker_sparql_builder_predicate (metadata, "slo:location");
 
-		tracker_sparql_builder_object_blank_open (metadata); /* GeoPoint */
+		tracker_sparql_builder_object_blank_open (metadata);
 		tracker_sparql_builder_predicate (metadata, "a");
-		tracker_sparql_builder_object (metadata, "slo:GeoLocation");
+		tracker_sparql_builder_object (metadata, "slo:GeoLocation"); /* GeoLocation */
 
-		if (md.address || md.state || md.country || md.city) {
-			gchar *addruri;
+		addruri = tracker_sparql_get_uuid_urn ();
 
-			addruri = tracker_sparql_get_uuid_urn ();
-
-			tracker_sparql_builder_predicate (metadata, "slo:postalAddress");
-			tracker_sparql_builder_object_iri (metadata, addruri);
-
-			tracker_sparql_builder_insert_open (preupdate, NULL);
-			tracker_sparql_builder_subject_iri (preupdate, addruri);
-
-			g_free (addruri);
-
-			tracker_sparql_builder_predicate (preupdate, "a");
-			tracker_sparql_builder_object (preupdate, "nco:PostalAddress");
-
-			if (md.address) {
-				tracker_sparql_builder_predicate (preupdate, "nco:streetAddress");
-				tracker_sparql_builder_object_unvalidated (preupdate, md.address);
-			}
-
-			if (md.state) {
-				tracker_sparql_builder_predicate (preupdate, "nco:region");
-				tracker_sparql_builder_object_unvalidated (preupdate, md.state);
-			}
-
-			if (md.city) {
-				tracker_sparql_builder_predicate (preupdate, "nco:locality");
-				tracker_sparql_builder_object_unvalidated (preupdate, md.city);
-			}
-
-			if (md.country) {
-				tracker_sparql_builder_predicate (preupdate, "nco:country");
-				tracker_sparql_builder_object_unvalidated (preupdate, md.country);
-			}
-
-			tracker_sparql_builder_insert_close (preupdate);
-		}
-
-		if (md.gps_altitude) {
-			tracker_sparql_builder_predicate (metadata, "slo:altitude");
-			tracker_sparql_builder_object_unvalidated (metadata, md.gps_altitude);
-		}
-
-		if (md.gps_latitude) {
-			tracker_sparql_builder_predicate (metadata, "slo:latitude");
-			tracker_sparql_builder_object_unvalidated (metadata, md.gps_latitude);
-		}
-
-		if (md.gps_longitude) {
-			tracker_sparql_builder_predicate (metadata, "slo:longitude");
-			tracker_sparql_builder_object_unvalidated (metadata, md.gps_longitude);
-		}
+		tracker_sparql_builder_predicate (metadata, "slo:postalAddress");
+		tracker_sparql_builder_object_iri (metadata, addruri);
 
 		tracker_sparql_builder_object_blank_close (metadata); /* GeoLocation */
-	}
 
-	if (md.gps_direction) {
-		tracker_sparql_builder_predicate (metadata, "nfo:heading");
-		tracker_sparql_builder_object_unvalidated (metadata, md.gps_direction);
+		tracker_sparql_builder_insert_open (preupdate, NULL);
+		tracker_sparql_builder_subject_iri (preupdate, addruri);
+
+		g_free (addruri);
+
+		tracker_sparql_builder_predicate (preupdate, "a");
+		tracker_sparql_builder_object (preupdate, "nco:PostalAddress");
+
+		if (md.address) {
+			tracker_sparql_builder_predicate (preupdate, "nco:streetAddress");
+			tracker_sparql_builder_object_unvalidated (preupdate, md.address);
+		}
+
+		if (md.state) {
+			tracker_sparql_builder_predicate (preupdate, "nco:region");
+			tracker_sparql_builder_object_unvalidated (preupdate, md.state);
+		}
+
+		if (md.city) {
+			tracker_sparql_builder_predicate (preupdate, "nco:locality");
+			tracker_sparql_builder_object_unvalidated (preupdate, md.city);
+		}
+
+		if (md.country) {
+			tracker_sparql_builder_predicate (preupdate, "nco:country");
+			tracker_sparql_builder_object_unvalidated (preupdate, md.country);
+		}
+
+		tracker_sparql_builder_insert_close (preupdate);
 	}
 
 	if (id->contact) {
@@ -622,10 +550,6 @@ extract_tiff (const gchar          *uri,
 		tracker_sparql_builder_predicate (metadata, "nao:hasTag");
 		tracker_sparql_builder_object_variable (metadata, var);
 
-		if (where == NULL) {
-			where = g_string_new ("} } WHERE { {\n");
-		}
-
 		g_string_append_printf (where, "?%s a nao:Tag ; nao:prefLabel \"%s\" .\n", var, escaped);
 
 		g_free (var);
@@ -791,20 +715,10 @@ extract_tiff (const gchar          *uri,
 		tracker_sparql_builder_object_double (metadata, value);
 	}
 
-	if (where != NULL) {
-		tracker_sparql_builder_append (metadata, where->str);
-		g_string_free (where, TRUE);
-	}
-
 	tiff_data_free (&td);
 	tracker_exif_free (ed);
 	tracker_xmp_free (xd);
 	tracker_iptc_free (id);
-	close (fd);
-}
 
-TrackerExtractData *
-tracker_extract_get_data (void)
-{
-	return extract_data;
+	return TRUE;
 }
