@@ -19,34 +19,10 @@
 
 #include "config.h"
 
-#ifndef _GNU_SOURCE
-#define _GNU_SOURCE
-#endif
-
-#include <errno.h>
-#include <fcntl.h>
-#include <string.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <unistd.h>
-#include <sys/mman.h>
-
-#include <glib.h>
-#include <glib/gstdio.h>
-
 #include <gio/gio.h>
 
 #include <libtracker-extract/tracker-extract.h>
 
-static void extract_xmp (const gchar          *filename,
-                         TrackerSparqlBuilder *preupdate,
-                         TrackerSparqlBuilder *metadata);
-
-static TrackerExtractData data[] = {
-	{ "application/rdf+xml", extract_xmp },
-	{ NULL, NULL }
-};
-
 /* This function is used to find the URI for a file.xmp file. The point here is
  * that the URI for file.xmp is not file:///file.xmp but instead for example
  * file:///file.jpeg or file:///file.png. The reason is that file.xmp is a
@@ -143,60 +119,22 @@ find_orig_uri (const gchar *xmp_filename)
 	return found_file;
 }
 
-static void
-extract_xmp (const gchar          *uri,
-             TrackerSparqlBuilder *preupdate,
-             TrackerSparqlBuilder *metadata)
+G_MODULE_EXPORT gboolean
+tracker_extract_get_metadata (const gchar          *uri,
+                              const gchar          *mimetype,
+                              TrackerSparqlBuilder *preupdate,
+                              TrackerSparqlBuilder *metadata,
+                              GString              *where)
 {
 	TrackerXmpData *xd = NULL;
+	GError *error = NULL;
 	gchar *filename;
 	gchar *contents;
-	gsize length = 0;
-	int fd;
-	struct stat st;
-
+	gsize length;
 
 	filename = g_filename_from_uri (uri, NULL, NULL);
 
-	fd = g_open (filename, O_RDONLY | O_NOATIME, 0);
-	if (fd == -1 && errno == EPERM) {
-		fd = g_open (filename, O_RDONLY, 0);
-	}
-
-	if (fd == -1) {
-		g_warning ("Could not open xmp file '%s': %s\n",
-		           filename,
-		           g_strerror (errno));
-		g_free (filename);
-		return;
-	}
-
-	if (fstat (fd, &st) == -1) {
-		g_warning ("Could not fstat xmp file '%s': %s\n",
-		           filename,
-		           g_strerror (errno));
-		close (fd);
-		g_free (filename);
-		return;
-	}
-
-	if (st.st_size == 0) {
-		contents = NULL;
-		length = 0;
-	} else {
-		contents = (gchar *) mmap (NULL, st.st_size, PROT_READ, MAP_PRIVATE, fd, 0);
-		if (contents == NULL) {
-			g_warning ("Could not mmap xmp file '%s': %s\n",
-			           filename,
-			           g_strerror (errno));
-			close (fd);
-			g_free (filename);
-			return;
-		}
-		length = st.st_size;
-	}
-
-	if (contents) {
+	if (g_file_get_contents (filename, &contents, &length, &error)) {
 		gchar *original_uri;
 
 		original_uri = find_orig_uri (filename);
@@ -209,21 +147,17 @@ extract_xmp (const gchar          *uri,
 		                      original_uri ? original_uri : uri);
 
 		if (xd) {
-			tracker_xmp_apply (preupdate, metadata, uri, xd);
+			tracker_xmp_apply (preupdate, metadata, where, uri, xd);
 		}
 
 		g_free (original_uri);
 		tracker_xmp_free (xd);
+		g_free (contents);
+		g_free (filename);
 
-		munmap (contents, length);
+		return TRUE;
 	}
 
-	close (fd);
 	g_free (filename);
-}
-
-TrackerExtractData *
-tracker_extract_get_data (void)
-{
-	return data;
+	return FALSE;
 }
