@@ -11,7 +11,7 @@ from dbus.mainloop.glib import DBusGMainLoop
 import time
 
 import options
-#from common.utils.options import get_start_timeout
+from dconf import DConfClient
 
 # Don't use /tmp (not enough space there)
 
@@ -22,14 +22,12 @@ TEST_ENV_DIRS =  { "XDG_DATA_HOME" : os.path.join (cfg.TEST_TMP_DIR, "xdg-data-h
                    "XDG_CACHE_HOME": os.path.join (cfg.TEST_TMP_DIR, "xdg-cache-home")}
 
 TEST_ENV_VARS = {  "TRACKER_DISABLE_MEEGOTOUCH_LOCALE": "",
-                   "LC_COLLATE": "en_GB.utf8"}
+                   "LC_COLLATE": "en_GB.utf8",
+                   "DCONF_PROFILE": "trackertest"}
 
 EXTRA_DIRS = [os.path.join (cfg.TEST_TMP_DIR, "xdg-data-home", "tracker"),
               os.path.join (cfg.TEST_TMP_DIR, "xdg-cache-home", "tracker")]
 
-# This variable is not in the dictionary because not all tests need to modify it!
-XDG_CONFIG_HOME_DIR = os.path.join (cfg.TEST_TMP_DIR, "xdg-config-home")
-
 REASONABLE_TIMEOUT = 30
 
 class UnableToBootException (Exception):
@@ -196,7 +194,7 @@ class TrackerMinerFsLifeCycle():
         self.loop.quit ()
         return False
 
-    def __minerfs_status_cb (self, status, handle):
+    def __minerfs_status_cb (self, status, progress, remaining_time):
         print "[miner-fs] status is now", status.encode ("utf-8")
         if (status == "Idle"):
             if (self.timeout_id != 0):
@@ -303,33 +301,41 @@ class TrackerWritebackLifeCycle():
 
 class TrackerSystemAbstraction:
 
-    def set_up_environment (self, confdir, ontodir):
+    def set_up_environment (self, gsettings, ontodir):
         """
         Sets up the XDG_*_HOME variables and make sure the directories exist
+
+        gsettings is a list of triplets (schema, key, value) that will be set/unset in gsetting
         """
+        assert not gsettings or type(gsettings) is list 
+
+        print "[Conf] Setting test environment..."
+        
         for var, directory in TEST_ENV_DIRS.iteritems ():
-            print "[Conf] Setting %s - %s" %(var, directory)
+            print "export %s=%s" %(var, directory)
             self.__recreate_directory (directory)
             os.environ [var] = directory
 
         for directory in EXTRA_DIRS:
             self.__recreate_directory (directory)
 
-        if confdir :
-            self.__recreate_directory (XDG_CONFIG_HOME_DIR)
-            shutil.copytree (os.path.join (confdir, "tracker"),
-                             os.path.join (XDG_CONFIG_HOME_DIR, "tracker"))
-            print "[Conf] Setting %s - %s" % ("XDG_CONFIG_HOME", XDG_CONFIG_HOME_DIR)
-            print "[Conf]   taking conf from", confdir
-            os.environ ["XDG_CONFIG_HOME"] = XDG_CONFIG_HOME_DIR
-
         if ontodir:
-            print "[Conf] Setting %s - %s" % ("TRACKER_DB_ONTOLOGIES_DIR", ontodir)
+            print "export %s=%s" % ("TRACKER_DB_ONTOLOGIES_DIR", ontodir)
             os.environ ["TRACKER_DB_ONTOLOGIES_DIR"] = ontodir
 
         for var, value in TEST_ENV_VARS.iteritems ():
+            print "export %s=%s" %(var, value)
             os.environ [var] = value
 
+        # Previous loop should have set DCONF_PROFILE to the test location
+        if gsettings:
+            self.dconf = DConfClient ()
+            self.dconf.reset ()
+            for (schema, key, value) in gsettings:
+                self.dconf.write (schema, key, value)
+
+        print "[Conf] environment ready"
+
     def unset_up_environment (self):
         """
         Unset the XDG_*_HOME variables from the environment
@@ -342,9 +348,6 @@ class TrackerSystemAbstraction:
             if os.environ.has_key (var):
                 del os.environ [var]
 
-        if (os.environ.has_key ("XDG_CONFIG_HOME")):
-            del os.environ ["XDG_CONFIG_HOME"]
-
         if (os.environ.has_key ("TRACKER_DB_ONTOLOGIES_DIR")):
             del os.environ ["TRACKER_DB_ONTOLOGIES_DIR"]
 
@@ -388,12 +391,11 @@ class TrackerSystemAbstraction:
         f.close ()
 
     def tracker_store_corrupt_dbs (self):
-        for filename in ["meta.db", "meta.db-wal"]:
-            db_path = os.path.join (TEST_ENV_DIRS ['XDG_CACHE_HOME'], "tracker", filename)
-            f = open (db_path, "w")
-            for i in range (0, 100):
-                f.write ("Some stupid content... hohohoho, not a sqlite file anymore!\n")
-            f.close ()
+        db_path = os.path.join (TEST_ENV_DIRS ['XDG_CACHE_HOME'], "tracker", "meta.db")
+        f = open (db_path, "w")
+        for i in range (0, 100):
+            f.write ("Some stupid content... hohohoho, not a sqlite file anymore!\n")
+        f.close ()
 
     def tracker_store_remove_journal (self):
         db_location = os.path.join (TEST_ENV_DIRS ['XDG_DATA_HOME'], "tracker", "data")
