@@ -22,6 +22,7 @@
 #include <string.h>
 
 #include <glib.h>
+#include <glib/gstdio.h>
 #include <gio/gio.h>
 
 #include <libtracker-common/tracker-ontologies.h>
@@ -74,8 +75,7 @@ test_sparql_query (gconstpointer test_data)
 	tracker_db_journal_set_rotating (FALSE, G_MAXSIZE, NULL);
 	tracker_data_manager_init (TRACKER_DB_MANAGER_FORCE_REINDEX,
 	                           test_schemas,
-	                           NULL, FALSE, FALSE,
-	                           100, 100, NULL, NULL, NULL, &error);
+	                           NULL, FALSE, 100, 100, NULL, NULL, NULL, &error);
 
 	g_assert_no_error (error);
 
@@ -178,6 +178,7 @@ main (int argc, char **argv)
 	gint result;
 	gint i;
 	gchar *current_dir;
+	gchar *path;
 
 	g_type_init ();
 
@@ -191,6 +192,7 @@ main (int argc, char **argv)
 
 	g_setenv ("XDG_DATA_HOME", current_dir, TRUE);
 	g_setenv ("XDG_CACHE_HOME", current_dir, TRUE);
+	g_setenv ("TRACKER_DB_SQL_DIR", TOP_SRCDIR "/data/db/", TRUE);
 	g_setenv ("TRACKER_DB_ONTOLOGIES_DIR", TOP_SRCDIR "/data/ontologies/", TRUE);
 	g_setenv ("TRACKER_FTS_STOP_WORDS", "0", TRUE);
 
@@ -212,5 +214,9 @@ main (int argc, char **argv)
 	g_print ("Removing temporary data\n");
 	g_spawn_command_line_sync ("rm -R tracker/", NULL, NULL, NULL, NULL);
 
+	path = g_build_filename (TOP_BUILDDIR, "tests", "libtracker-fts", "dconf", "user", NULL);
+	g_unlink (path);
+	g_free (path);
+
 	return result;
 }
